@@ -205,12 +205,14 @@ private:
   inline
   bool team_fan_in() const
     {
+      memory_fence();
       for ( int n = 1 , j ; ( ( j = m_team_rank_rev + n ) < m_team_size ) && ! ( m_team_rank_rev & n ) ; n <<= 1 ) {
         m_exec.pool_rev( m_team_base_rev + j )->state_wait( Active );
       }
 
       if ( m_team_rank_rev ) {
         m_exec.state_set( Rendezvous );
+        memory_fence();
         m_exec.state_wait( Rendezvous );
       }
 
@@ -220,8 +222,10 @@ private:
   inline
   void team_fan_out() const
     {
+      memory_fence();
       for ( int n = 1 , j ; ( ( j = m_team_rank_rev + n ) < m_team_size ) && ! ( m_team_rank_rev & n ) ; n <<= 1 ) {
         m_exec.pool_rev( m_team_base_rev + j )->state_set( Active );
+        memory_fence();
       }
     }
 
@@ -277,6 +281,7 @@ public:
     { return ValueType(); }
   #else
     {
+      memory_fence();
       typedef ValueType value_type;
       const JoinLambdaAdapter<value_type,JoinOp> op(op_in);
   #endif
@@ -313,6 +318,7 @@ public:
         for ( int i = 1 ; i < m_team_size ; ++i ) {
           op.join( *team_value , *((type*) m_exec.pool_rev( m_team_base_rev + i )->scratch_thread()) );
         }
+        memory_fence();
 
         // The base team member may "lap" the other team members,
         // copy to their local value before proceeding.
@@ -496,6 +502,8 @@ private:
   int m_team_alloc ;
   int m_team_iter ;
 
+  size_t m_scratch_size;
+
   inline void init( const int league_size_request
                   , const int team_size_request )
     {
@@ -523,30 +531,50 @@ public:
 
   inline int team_size()   const { return m_team_size ; }
   inline int league_size() const { return m_league_size ; }
+  inline size_t scratch_size() const { return m_scratch_size ; }
 
   /** \brief  Specify league size, request team size */
   TeamPolicy( execution_space &
             , int league_size_request
             , int team_size_request
             , int /* vector_length_request */ = 1 )
+            : m_scratch_size ( 0 )
     { init( league_size_request , team_size_request ); }
 
   TeamPolicy( execution_space &
             , int league_size_request
             , const Kokkos::AUTO_t & /* team_size_request */
             , int /* vector_length_request */ = 1)
+            : m_scratch_size ( 0 )
     { init( league_size_request , execution_space::thread_pool_size(2) ); }
 
   TeamPolicy( int league_size_request
             , int team_size_request
             , int /* vector_length_request */ = 1 )
+            : m_scratch_size ( 0 )
     { init( league_size_request , team_size_request ); }
 
   TeamPolicy( int league_size_request
             , const Kokkos::AUTO_t & /* team_size_request */
             , int /* vector_length_request */ = 1 )
+            : m_scratch_size ( 0 )
     { init( league_size_request , execution_space::thread_pool_size(2) ); }
 
+  template<class MemorySpace>
+  TeamPolicy( int league_size_request
+            , int team_size_request
+            , const Experimental::TeamScratchRequest<MemorySpace> & scratch_request )
+            : m_scratch_size(scratch_request.total(team_size_request))
+    { init(league_size_request,team_size_request); }
+
+
+  template<class MemorySpace>
+  TeamPolicy( int league_size_request
+            , const Kokkos::AUTO_t & /* team_size_request */
+            , const Experimental::TeamScratchRequest<MemorySpace> & scratch_request )
+            : m_scratch_size(scratch_request.total(execution_space::thread_pool_size(2)))
+    { init(league_size_request,execution_space::thread_pool_size(2)); }
+
   inline int team_alloc() const { return m_team_alloc ; }
   inline int team_iter()  const { return m_team_iter ; }
 
