@@ -53,17 +53,6 @@
 
 namespace Test {
 
-template< class RangeType >
-void test_view_range( const size_t N , const RangeType & range , const size_t begin , const size_t dim )
-{
-  typedef Kokkos::Experimental::Impl::ViewOffsetRange< RangeType >  query ;
-
-  ASSERT_EQ( query::begin( range ) , begin );
-  ASSERT_EQ( query::dimension( N , range ) , dim );
-  ASSERT_EQ( query::is_range , dim != 0 );
-}
-
-
 template< class ExecSpace >
 void test_view_mapping()
 {
@@ -397,6 +386,38 @@ void test_view_mapping()
 
   //----------------------------------------
   // Subview
+  {
+    // Mapping rank 4 to rank 3
+    typedef Kokkos::Experimental::Impl::SubviewExtents<4,3> SubviewExtents ;
+
+    constexpr int N0 = 1000 ;
+    constexpr int N1 = 2000 ;
+    constexpr int N2 = 3000 ;
+    constexpr int N3 = 4000 ;
+
+    Kokkos::Experimental::Impl::ViewDimension<N0,N1,N2,N3> dim ;
+
+    SubviewExtents tmp( dim
+                      , N0 / 2
+                      , Kokkos::Experimental::ALL
+                      , std::pair<int,int>( N2 / 4 , 10 + N2 / 4 )
+                      , Kokkos::pair<int,int>( N3 / 4 , 20 + N3 / 4 )
+                      );
+
+    ASSERT_EQ( tmp.domain_offset(0) , N0 / 2 );
+    ASSERT_EQ( tmp.domain_offset(1) , 0 );
+    ASSERT_EQ( tmp.domain_offset(2) , N2 / 4 );
+    ASSERT_EQ( tmp.domain_offset(3) , N3 / 4 );
+
+    ASSERT_EQ( tmp.range_index(0) , 1 );
+    ASSERT_EQ( tmp.range_index(1) , 2 );
+    ASSERT_EQ( tmp.range_index(2) , 3 );
+
+    ASSERT_EQ( tmp.range_extent(0) , N1 );
+    ASSERT_EQ( tmp.range_extent(1) , 10 );
+    ASSERT_EQ( tmp.range_extent(2) , 20 );
+  }
+  //----------------------------------------
   {
     constexpr int N0 = 2000 ;
     constexpr int N1 = 300 ;
@@ -409,7 +430,14 @@ void test_view_mapping()
 
     left_s0_s0_s4 dyn_off3( std::integral_constant<unsigned,sizeof(int)>(), N0, N1, 0, 0, 0, 0, 0, 0 );
 
-    stride_s0_s0_s0  stride3( dyn_off3 , sub_N0 , sub_N1 , sub_N2 , 0 , 0 , 0 , 0 , 0 );
+    Kokkos::Experimental::Impl::SubviewExtents< 3 , 3 >
+      sub( dyn_off3.m_dim
+         , Kokkos::pair<int,int>(0,sub_N0)
+         , Kokkos::pair<int,int>(0,sub_N1)
+         , Kokkos::pair<int,int>(0,sub_N2)
+         );
+
+    stride_s0_s0_s0  stride3( dyn_off3 , sub );
 
     ASSERT_EQ( stride3.dimension_0() , sub_N0 );
     ASSERT_EQ( stride3.dimension_1() , sub_N1 );
@@ -440,7 +468,14 @@ void test_view_mapping()
 
     right_s0_s0_s4 dyn_off3( std::integral_constant<unsigned,sizeof(int)>(), N0, N1, 0, 0, 0, 0, 0, 0 );
 
-    stride_s0_s0_s0  stride3( dyn_off3 , sub_N0 , sub_N1 , sub_N2 , 0 , 0 , 0 , 0 , 0 );
+    Kokkos::Experimental::Impl::SubviewExtents< 3 , 3 >
+      sub( dyn_off3.m_dim
+         , Kokkos::pair<int,int>(0,sub_N0)
+         , Kokkos::pair<int,int>(0,sub_N1)
+         , Kokkos::pair<int,int>(0,sub_N2)
+         );
+
+    stride_s0_s0_s0  stride3( dyn_off3 , sub );
 
     ASSERT_EQ( stride3.dimension_0() , sub_N0 );
     ASSERT_EQ( stride3.dimension_1() , sub_N1 );
@@ -459,17 +494,16 @@ void test_view_mapping()
     }}}
   }
 
-  //----------------------------------------
-  {
-    constexpr int N = 1000 ;
-
-    test_view_range( N , N / 2 , N / 2 , 0 );
-    test_view_range( N , Kokkos::Experimental::ALL , 0 , N );
-    test_view_range( N , std::pair<int,int>( N / 4 , 10 + N / 4 ) , N / 4 , 10 );
-    test_view_range( N , Kokkos::pair<int,int>( N / 4 , 10 + N / 4 ) , N / 4 , 10 );
-  }
   //----------------------------------------
   // view data analysis
+  {
+    using namespace Kokkos::Experimental::Impl ;
+    static_assert( rank_dynamic<>::value == 0 , "" );
+    static_assert( rank_dynamic<1>::value == 0 , "" );
+    static_assert( rank_dynamic<0>::value == 1 , "" );
+    static_assert( rank_dynamic<0,1>::value == 1 , "" );
+    static_assert( rank_dynamic<0,0,1>::value == 2 , "" );
+  }
 
   {
     using namespace Kokkos::Experimental::Impl ;
@@ -491,7 +525,9 @@ void test_view_mapping()
 
     static_assert( a_const_int_r5::dimension::rank == 5 , "" );
     static_assert( a_const_int_r5::dimension::rank_dynamic == 2 , "" );
+
     static_assert( std::is_same< typename a_const_int_r5::dimension , ViewDimension<0,0,4,5,6> >::value , "" );
+
     static_assert( std::is_same< typename a_const_int_r5::non_const_value_type , int >::value , "" );
 
     static_assert( a_int_r5::dimension::rank == 5 , "" );
@@ -510,18 +546,18 @@ void test_view_mapping()
 
     static_assert( a_int_r5::dimension::rank == 5 , "" );
     static_assert( a_int_r5::dimension::rank_dynamic == 3 , "" );
-    static_assert( a_int_r5::dimension::arg_N0 == 0 , "" );
-    static_assert( a_int_r5::dimension::arg_N1 == 0 , "" );
-    static_assert( a_int_r5::dimension::arg_N2 == 0 , "" );
-    static_assert( a_int_r5::dimension::arg_N3 == 3 , "" );
-    static_assert( a_int_r5::dimension::arg_N4 == 4 , "" );
+    static_assert( a_int_r5::dimension::ArgN0 == 0 , "" );
+    static_assert( a_int_r5::dimension::ArgN1 == 0 , "" );
+    static_assert( a_int_r5::dimension::ArgN2 == 0 , "" );
+    static_assert( a_int_r5::dimension::ArgN3 == 3 , "" );
+    static_assert( a_int_r5::dimension::ArgN4 == 4 , "" );
     static_assert( std::is_same< typename a_int_r5::non_const_value_type , int >::value , "" );
   }
 
   {
     using namespace Kokkos::Experimental::Impl ;
 
-    typedef ViewDataAnalysis< const int[] , typename ViewArrayAnalysis<const int[]>::non_const_value_type , void >  a_const_int_r1 ;
+    typedef ViewDataAnalysis< const int[] , void >  a_const_int_r1 ;
 
     static_assert( std::is_same< typename a_const_int_r1::specialize , void >::value , "" );
     static_assert( std::is_same< typename a_const_int_r1::dimension , Kokkos::Experimental::Impl::ViewDimension<0> >::value , "" );
@@ -536,10 +572,12 @@ void test_view_mapping()
     static_assert( std::is_same< typename a_const_int_r1::non_const_type , int * >::value , "" );
     static_assert( std::is_same< typename a_const_int_r1::non_const_value_type , int >::value , "" );
 
-    typedef ViewDataAnalysis< const int**[4] , typename ViewArrayAnalysis< const int **[4] >::non_const_value_type , void >  a_const_int_r3 ;
+    typedef ViewDataAnalysis< const int**[4] , void >  a_const_int_r3 ;
 
     static_assert( std::is_same< typename a_const_int_r3::specialize , void >::value , "" );
+
     static_assert( std::is_same< typename a_const_int_r3::dimension , Kokkos::Experimental::Impl::ViewDimension<0,0,4> >::value , "" );
+
     static_assert( std::is_same< typename a_const_int_r3::type , const int**[4] >::value , "" );
     static_assert( std::is_same< typename a_const_int_r3::value_type , const int >::value , "" );
     static_assert( std::is_same< typename a_const_int_r3::array_scalar_type , const int**[4] >::value , "" );
@@ -564,8 +602,9 @@ void test_view_mapping()
 
     int data[N] ;
 
-    T vr1(data,N);
-    C cr1(vr1);
+    T vr1(data,N); // view of non-const
+    C cr1(vr1);    // view of const from view of non-const
+    C cr2( (const int *) data , N );
 
     // Generate static_assert error:
     // T tmp( cr1 );
@@ -761,42 +800,100 @@ void test_view_mapping()
     ASSERT_EQ( d.dimension_0() , 5 );
     ASSERT_EQ( d.dimension_1() , 6 );
   }
+
+#if defined( KOKKOS_USING_EXPERIMENTAL_VIEW )
+  /* Only works when experimental view is activated */
+  {
+    typedef Kokkos::Experimental::View<int*,ExecSpace> V ;
+    typedef Kokkos::Experimental::View<int*,ExecSpace,Kokkos::MemoryUnmanaged> U ;
+
+
+    V a("a",10);
+
+    ASSERT_EQ( a.use_count() , 1 );
+
+    V b = a ;
+
+    ASSERT_EQ( a.use_count() , 2 );
+    ASSERT_EQ( b.use_count() , 2 );
+
+    {
+      U c = b ; // 'c' is compile-time unmanaged
+
+      ASSERT_EQ( a.use_count() , 2 );
+      ASSERT_EQ( b.use_count() , 2 );
+      ASSERT_EQ( c.use_count() , 2 );
+
+      V d = c ; // 'd' is run-time unmanaged
+
+      ASSERT_EQ( a.use_count() , 2 );
+      ASSERT_EQ( b.use_count() , 2 );
+      ASSERT_EQ( c.use_count() , 2 );
+      ASSERT_EQ( d.use_count() , 2 );
+    }
+
+    ASSERT_EQ( a.use_count() , 2 );
+    ASSERT_EQ( b.use_count() , 2 );
+
+    b = V();
+
+    ASSERT_EQ( a.use_count() , 1 );
+    ASSERT_EQ( b.use_count() , 0 );
+
+    Kokkos::parallel_for(
+      Kokkos::RangePolicy< Kokkos::DefaultHostExecutionSpace >(0,10) ,
+      [=]( int i ){
+        // 'a' is captured by copy and the capture mechanism
+        // converts 'a' to an unmanaged copy.
+        // When the parallel dispatch accepts a move for the lambda
+        // this count should become 1
+        ASSERT_EQ( a.use_count() , 2 );
+        V x = a ;
+        ASSERT_EQ( a.use_count() , 2 );
+        ASSERT_EQ( x.use_count() , 2 );
+      });
+  }
+#endif /* #if defined( KOKKOS_USING_EXPERIMENTAL_VIEW ) */
 }
 
 template< class ExecSpace >
 struct TestViewMappingSubview {
 
-  constexpr static int AN = 10 ;
+  typedef Kokkos::pair<int,int> range ;
+
+  enum { AN = 10 };
   typedef Kokkos::Experimental::View<int*,ExecSpace>  AT ;
-  typedef Kokkos::Experimental::Subview< AT , true >  AS ;
+  typedef Kokkos::Experimental::View<const int*,ExecSpace>  ACT ;
+  typedef Kokkos::Experimental::Subview< AT , range >  AS ;
 
-  constexpr static int BN0 = 10 , BN1 = 11 , BN2 = 12 ;
+  enum { BN0 = 10 , BN1 = 11 , BN2 = 12 };
   typedef Kokkos::Experimental::View<int***,ExecSpace>  BT ;
-  typedef Kokkos::Experimental::Subview< BT , true , true , true >  BS ;
+  typedef Kokkos::Experimental::Subview< BT , range , range , range >  BS ;
 
-  constexpr static int CN0 = 10 , CN1 = 11 , CN2 = 12 ;
+  enum { CN0 = 10 , CN1 = 11 , CN2 = 12 };
   typedef Kokkos::Experimental::View<int***[13][14],ExecSpace>  CT ;
-  typedef Kokkos::Experimental::Subview< CT , true , true , true , false , false >  CS ;
+  typedef Kokkos::Experimental::Subview< CT , range , range , range , int , int >  CS ;
 
-  constexpr static int DN0 = 10 , DN1 = 11 , DN2 = 12 ;
-  typedef Kokkos::Experimental::View<int***[13][14],ExecSpace>  DT ;
-  typedef Kokkos::Experimental::Subview< DT , false , true , true , true , false >  DS ;
+  enum { DN0 = 10 , DN1 = 11 , DN2 = 12 , DN3 = 13 , DN4 = 14 };
+  typedef Kokkos::Experimental::View<int***[DN3][DN4],ExecSpace>  DT ;
+  typedef Kokkos::Experimental::Subview< DT , int , range , range , range , int >  DS ;
 
 
   typedef Kokkos::Experimental::View<int***[13][14],Kokkos::LayoutLeft,ExecSpace>  DLT ;
-  typedef Kokkos::Experimental::Subview< DLT , true , false , false , false , false >  DLS1 ;
+  typedef Kokkos::Experimental::Subview< DLT , range , int , int , int , int >  DLS1 ;
 
   static_assert( DLS1::rank == 1 && std::is_same< typename DLS1::array_layout , Kokkos::LayoutLeft >::value
                , "Subview layout error for rank 1 subview of left-most range of LayoutLeft" );
 
   typedef Kokkos::Experimental::View<int***[13][14],Kokkos::LayoutRight,ExecSpace>  DRT ;
-  typedef Kokkos::Experimental::Subview< DRT , false , false , false , false , true >  DRS1 ;
+  typedef Kokkos::Experimental::Subview< DRT , int , int , int , int , range >  DRS1 ;
 
   static_assert( DRS1::rank == 1 && std::is_same< typename DRS1::array_layout , Kokkos::LayoutRight >::value
                , "Subview layout error for rank 1 subview of right-most range of LayoutRight" );
 
   AT Aa ;
   AS Ab ;
+  ACT Ac ;
   BT Ba ;
   BS Bb ;
   CT Ca ;
@@ -807,6 +904,7 @@ struct TestViewMappingSubview {
   TestViewMappingSubview()
     : Aa("Aa",AN)
     , Ab( Kokkos::Experimental::subview( Aa , std::pair<int,int>(1,AN-1) ) )
+    , Ac( Aa , std::pair<int,int>(1,AN-1) )
     , Ba("Ba",BN0,BN1,BN2)
     , Bb( Kokkos::Experimental::subview( Ba
                                         , std::pair<int,int>(1,BN0-1)
@@ -824,9 +922,9 @@ struct TestViewMappingSubview {
     , Da("Da",DN0,DN1,DN2)
     , Db( Kokkos::Experimental::subview( Da
                                         , 1
-                                        , std::pair<int,int>(1,DN0-1)
                                         , std::pair<int,int>(1,DN1-1)
                                         , std::pair<int,int>(1,DN2-1)
+                                        , std::pair<int,int>(1,DN3-1)
                                         , 2
                                         ) )
     {
@@ -836,7 +934,11 @@ struct TestViewMappingSubview {
   KOKKOS_INLINE_FUNCTION
   void operator()( const int , long & error_count ) const
     {
+      auto Ad = Kokkos::Experimental::subview< Kokkos::MemoryUnmanaged >( Aa , Kokkos::pair<int,int>(1,AN-1) );
+
       for ( int i = 1 ; i < AN-1 ; ++i ) if( & Aa[i] != & Ab[i-1] ) ++error_count ;
+      for ( int i = 1 ; i < AN-1 ; ++i ) if( & Aa[i] != & Ac[i-1] ) ++error_count ;
+      for ( int i = 1 ; i < AN-1 ; ++i ) if( & Aa[i] != & Ad[i-1] ) ++error_count ;
 
       for ( int i2 = 1 ; i2 < BN2-1 ; ++i2 ) {
       for ( int i1 = 1 ; i1 < BN1-1 ; ++i1 ) {
@@ -850,9 +952,9 @@ struct TestViewMappingSubview {
         if ( & Ca(i0,i1,i2,1,2) != & Cb(i0-1,i1-1,i2-1) ) ++error_count ;
       }}}
 
-      for ( int i2 = 1 ; i2 < DN2-1 ; ++i2 ) {
-      for ( int i1 = 1 ; i1 < DN1-1 ; ++i1 ) {
-      for ( int i0 = 1 ; i0 < DN0-1 ; ++i0 ) {
+      for ( int i2 = 1 ; i2 < DN3-1 ; ++i2 ) {
+      for ( int i1 = 1 ; i1 < DN2-1 ; ++i1 ) {
+      for ( int i0 = 1 ; i0 < DN1-1 ; ++i0 ) {
         if ( & Da(1,i0,i1,i2,2) != & Db(i0-1,i1-1,i2-1) ) ++error_count ;
       }}}
     }
@@ -861,6 +963,35 @@ struct TestViewMappingSubview {
   {
     TestViewMappingSubview self ;
 
+    ASSERT_EQ( self.Aa.dimension_0() , AN );
+    ASSERT_EQ( self.Ab.dimension_0() , AN - 2 );
+    ASSERT_EQ( self.Ac.dimension_0() , AN - 2 );
+    ASSERT_EQ( self.Ba.dimension_0() , BN0 );
+    ASSERT_EQ( self.Ba.dimension_1() , BN1 );
+    ASSERT_EQ( self.Ba.dimension_2() , BN2 );
+    ASSERT_EQ( self.Bb.dimension_0() , BN0 - 2 );
+    ASSERT_EQ( self.Bb.dimension_1() , BN1 - 2 );
+    ASSERT_EQ( self.Bb.dimension_2() , BN2 - 2 );
+
+    ASSERT_EQ( self.Ca.dimension_0() , CN0 );
+    ASSERT_EQ( self.Ca.dimension_1() , CN1 );
+    ASSERT_EQ( self.Ca.dimension_2() , CN2 );
+    ASSERT_EQ( self.Ca.dimension_3() , 13 );
+    ASSERT_EQ( self.Ca.dimension_4() , 14 );
+    ASSERT_EQ( self.Cb.dimension_0() , CN0 - 2 );
+    ASSERT_EQ( self.Cb.dimension_1() , CN1 - 2 );
+    ASSERT_EQ( self.Cb.dimension_2() , CN2 - 2 );
+
+    ASSERT_EQ( self.Da.dimension_0() , DN0 );
+    ASSERT_EQ( self.Da.dimension_1() , DN1 );
+    ASSERT_EQ( self.Da.dimension_2() , DN2 );
+    ASSERT_EQ( self.Da.dimension_3() , DN3 );
+    ASSERT_EQ( self.Da.dimension_4() , DN4 );
+
+    ASSERT_EQ( self.Db.dimension_0() , DN1 - 2 );
+    ASSERT_EQ( self.Db.dimension_1() , DN2 - 2 );
+    ASSERT_EQ( self.Db.dimension_2() , DN3 - 2 );
+
     ASSERT_EQ( self.Da.stride_1() , self.Db.stride_0() );
     ASSERT_EQ( self.Da.stride_2() , self.Db.stride_1() );
     ASSERT_EQ( self.Da.stride_3() , self.Db.stride_2() );
