@@ -124,9 +124,13 @@ void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::setProblemMatrix(
 
   A_=A;
   if(A_!=Teuchos::null)
-    TpetraA_ = Utils::Op2NonConstTpetraCrs(A_);
+    TpetraA_ = Utilities::Op2NonConstTpetraCrs(A_);
+#ifdef HAVE_MUELU_TPETRA_INST_INT_INT
   if(LinearProblem_!=Teuchos::null)
     LinearProblem_ -> setOperator ( TpetraA_ );
+#else
+  TEUCHOS_TEST_FOR_EXCEPTION(true, Exceptions::RuntimeError, "ShiftedLaplacian only available with Tpetra and GO=int enabled.");
+#endif
 
 }
 
@@ -134,8 +138,10 @@ template<class Scalar, class LocalOrdinal, class GlobalOrdinal, class Node>
 void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::setProblemMatrix(RCP< Tpetra::CrsMatrix<SC,LO,GO,NO> >& TpetraA) {
 
   TpetraA_=TpetraA;
+#ifdef HAVE_MUELU_TPETRA_INST_INT_INT
   if(LinearProblem_!=Teuchos::null)
     LinearProblem_ -> setOperator ( TpetraA_ );
+#endif
 
 }
 
@@ -328,6 +334,7 @@ void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::initialize() {
     precList_.set("ColPerm", ilu_colperm_);
     precList_.set("DiagPivotThresh", ilu_diagpivotthresh_);
   }
+#ifdef HAVE_MUELU_TPETRA_INST_INT_INT
   // construct smoother
   smooProto_ = rcp( new Ifpack2Smoother(precType_,precList_) );
   smooFact_  = rcp( new SmootherFactory(smooProto_) );
@@ -391,7 +398,9 @@ void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::initialize() {
   BelosList_ -> set("Output Style",Belos::Brief);
   BelosList_ -> set("Num Blocks",restart_size_);
   BelosList_ -> set("Num Recycled Blocks",recycle_size_);
-
+#else
+  TEUCHOS_TEST_FOR_EXCEPTION(true, Exceptions::RuntimeError, "ShiftedLaplacian only available with Tpetra and GO=int enabled.");
+#endif
 }
 
 // setup coarse grids for new frequency
@@ -448,6 +457,7 @@ void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::setupNormalRAP()
 template<class Scalar, class LocalOrdinal, class GlobalOrdinal, class Node>
 void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::setupSolver() {
 
+#ifdef HAVE_MUELU_TPETRA_INST_INT_INT
   // Define Preconditioner and Operator
   MueLuOp_ = rcp( new MueLu::ShiftedLaplacianOperator<SC,LO,GO,NO>
                   (Hierarchy_, A_, ncycles_, subiters_, option_, tol_) );
@@ -465,23 +475,33 @@ void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::setupSolver() {
     SolverManager_ = SolverFactory_->create( solverName, BelosList_ );
     SolverManager_ -> setProblem( LinearProblem_ );
   }
-
+#else
+  TEUCHOS_TEST_FOR_EXCEPTION(true, Exceptions::RuntimeError, "ShiftedLaplacian only available with Tpetra and GO=int enabled.");
+#endif
 }
 
 template<class Scalar, class LocalOrdinal, class GlobalOrdinal, class Node>
 void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::resetLinearProblem()
 {
+#ifdef HAVE_MUELU_TPETRA_INST_INT_INT
   LinearProblem_ -> setOperator (  TpetraA_  );
+#else
+  TEUCHOS_TEST_FOR_EXCEPTION(true, Exceptions::RuntimeError, "ShiftedLaplacian only available with Tpetra and GO=int enabled.");
+#endif
 }
 
 // Solve phase
 template<class Scalar, class LocalOrdinal, class GlobalOrdinal, class Node>
 int ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::solve(const RCP<TMV> B, RCP<TMV>& X)
 {
+#ifdef HAVE_MUELU_TPETRA_INST_INT_INT
   // Set left and right hand sides for Belos
   LinearProblem_ -> setProblem(X, B);
   // iterative solve
   SolverManager_ -> solve();
+#else
+  TEUCHOS_TEST_FOR_EXCEPTION(true, Exceptions::RuntimeError, "ShiftedLaplacian only available with Tpetra and GO=int enabled.");
+#endif
   return 0;
 }
 
@@ -511,16 +531,26 @@ void ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::multigrid_apply(c
 template<class Scalar, class LocalOrdinal, class GlobalOrdinal, class Node>
 int ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::GetIterations()
 {
+#ifdef HAVE_MUELU_TPETRA_INST_INT_INT
   int numiters = SolverManager_ -> getNumIters();
   return numiters;
+#else
+  TEUCHOS_TEST_FOR_EXCEPTION(true, Exceptions::RuntimeError, "ShiftedLaplacian only available with Tpetra and GO=int enabled.");
+  return -1;
+#endif
 }
 
 // Get most recent solver tolerance achieved
 template<class Scalar, class LocalOrdinal, class GlobalOrdinal, class Node>
 double ShiftedLaplacian<Scalar,LocalOrdinal,GlobalOrdinal,Node>::GetResidual()
 {
+#ifdef HAVE_MUELU_TPETRA_INST_INT_INT
   double residual = SolverManager_ -> achievedTol();
   return residual;
+#else
+  TEUCHOS_TEST_FOR_EXCEPTION(true, Exceptions::RuntimeError, "ShiftedLaplacian only available with Tpetra and GO=int enabled.");
+  return -1.0;
+#endif
 }
 
 }
