@@ -47,6 +47,8 @@
 
 #include <MueLu_ConfigDefs.hpp>
 
+#include <Kokkos_DefaultNode.hpp> // For Epetra only runs this points to FakeKokkos in Xpetra
+
 #include <Teuchos_XMLParameterListHelpers.hpp> // getParametersFromXmlFile()
 //#include <Teuchos_XMLParameterListCoreHelpers.hpp>
 
@@ -78,7 +80,17 @@
 // Teuchos
 #include <Teuchos_StandardCatchMacros.hpp>
 
-#include <MueLu_UseDefaultTypes.hpp>
+// Define default data types
+typedef double Scalar;
+typedef int LocalOrdinal;
+typedef int GlobalOrdinal;
+
+// choose computational node
+#if defined(HAVE_MUELU_EPETRA) and defined(HAVE_MUELU_SERIAL)
+  typedef Kokkos::Compat::KokkosSerialWrapperNode Node;
+#elif defined(HAVE_MUELU_TPETRA)
+  typedef KokkosClassic::DefaultNode::DefaultNodeType Node;
+#endif
 
 // Default problem is Laplace1D with nx = 8748. Use --help to list available options.
 
@@ -114,7 +126,7 @@ int main(int argc, char *argv[]) {
 
     std::string xmlFileName; clp.setOption("xml",   &xmlFileName, "read parameters from a file. Otherwise, this example uses by default an hard-coded parameter list.");
     int muelu = true;            clp.setOption("muelu",  &muelu,             "use muelu through MLParameterListInterpreter");
-    int translatedmuelu = true;  clp.setOption("muelu2", &translatedmuelu,   "use muelu through XML parameter translation and ParameterListInterpreter"); 
+    int translatedmuelu = true;  clp.setOption("muelu2", &translatedmuelu,   "use muelu through XML parameter translation and ParameterListInterpreter");
     int ml    = true;
 #if defined(HAVE_MUELU_ML) && defined(HAVE_MUELU_EPETRA)
     clp.setOption("ml",    &ml,          "use ml");
@@ -127,9 +139,9 @@ int main(int argc, char *argv[]) {
       case Teuchos::CommandLineProcessor::PARSE_SUCCESSFUL:                               break;
     }
 
-    // TODO: check -ml and --linAlgebra
-
     if (comm->getRank() == 0) { std::cout << xpetraParameters << matrixParameters; }
+
+    // choose ML and Tpetra
     if (ml && xpetraParameters.GetLib() == Xpetra::UseTpetra) {
       ml = false;
       std::cout << "ML preconditionner can only be built if --linAlgebra=Epetra. Option --ml ignored" << std::endl;
@@ -181,7 +193,7 @@ int main(int argc, char *argv[]) {
       //
 
       std::cout << MueLu::ML2MueLuParameterTranslator::translate(*params, "SA") << std::endl;
-      
+
       // Multigrid Hierarchy
       MLParameterListInterpreter mueLuFactory(*params);
       RCP<Hierarchy> H = mueLuFactory.CreateHierarchy();
@@ -227,11 +239,11 @@ int main(int argc, char *argv[]) {
       H->Iterate(*B, *X, nIts);
 
       // Print relative residual norm
-      Teuchos::ScalarTraits<SC>::magnitudeType residualNorms = Utils::ResidualNorm(*A, *X, *B)[0];
+      Teuchos::ScalarTraits<SC>::magnitudeType residualNorms = Utilities::ResidualNorm(*A, *X, *B)[0];
       if (comm->getRank() == 0)
         std::cout << "||Residual|| = " << residualNorms << std::endl;
 
-#if defined(HAVE_MUELU_EPETRA) && defined(HAVE_MUELU_AZTECOO)
+#if defined(HAVE_MUELU_EPETRA) && defined(HAVE_MUELU_SERIAL) && defined(HAVE_MUELU_AZTECOO)
       if (xpetraParameters.GetLib() == Xpetra::UseEpetra) { //TODO: should be doable with Tpetra too
 
         // AMG as a preconditioner
@@ -269,10 +281,10 @@ int main(int argc, char *argv[]) {
         solver.Iterate(nIts, 1e-10);
 
         { //TODO: simplify this
-          RCP<Vector> mueluX = rcp(new Xpetra::EpetraVector(eX));
-          RCP<Vector> mueluB = rcp(new Xpetra::EpetraVector(eB));
+          RCP<Vector> mueluX = rcp(new Xpetra::EpetraVectorT<int,Node>(eX));
+          RCP<Vector> mueluB = rcp(new Xpetra::EpetraVectorT<int,Node>(eB));
           // Print relative residual norm
-          Teuchos::ScalarTraits<SC>::magnitudeType residualNorms2 = Utils::ResidualNorm(*A, *mueluX, *mueluB)[0];
+          Teuchos::ScalarTraits<SC>::magnitudeType residualNorms2 = Utilities::ResidualNorm(*A, *mueluX, *mueluB)[0];
           if (comm->getRank() == 0)
             std::cout << "||Residual|| = " << residualNorms2 << std::endl;
         }
@@ -283,7 +295,7 @@ int main(int argc, char *argv[]) {
 
     } // if (muelu)
 
-    
+
     if ( translatedmuelu ) {
        //
       // Construct a multigrid preconditioner
@@ -291,7 +303,7 @@ int main(int argc, char *argv[]) {
 
       RCP<ParameterList> mueluParams = Teuchos::getParametersFromXmlString(MueLu::ML2MueLuParameterTranslator::translate(*params, "SA"));
       std::cout << MueLu::ML2MueLuParameterTranslator::translate(*params, "SA") << std::endl;
-      
+
       // Multigrid Hierarchy
       ParameterListInterpreter mueLuFactory(*mueluParams);
       RCP<Hierarchy> H = mueLuFactory.CreateHierarchy();
@@ -337,11 +349,11 @@ int main(int argc, char *argv[]) {
       H->Iterate(*B, *X, nIts);
 
       // Print relative residual norm
-      Teuchos::ScalarTraits<SC>::magnitudeType residualNorms = Utils::ResidualNorm(*A, *X, *B)[0];
+      Teuchos::ScalarTraits<SC>::magnitudeType residualNorms = Utilities::ResidualNorm(*A, *X, *B)[0];
       if (comm->getRank() == 0)
         std::cout << "||Residual|| = " << residualNorms << std::endl;
 
-#if defined(HAVE_MUELU_EPETRA) && defined(HAVE_MUELU_AZTECOO)
+#if defined(HAVE_MUELU_EPETRA) && defined(HAVE_MUELU_SERIAL) && defined(HAVE_MUELU_AZTECOO)
       if (xpetraParameters.GetLib() == Xpetra::UseEpetra) { //TODO: should be doable with Tpetra too
 
         // AMG as a preconditioner
@@ -379,19 +391,19 @@ int main(int argc, char *argv[]) {
         solver.Iterate(nIts, 1e-10);
 
         { //TODO: simplify this
-          RCP<Vector> mueluX = rcp(new Xpetra::EpetraVector(eX));
-          RCP<Vector> mueluB = rcp(new Xpetra::EpetraVector(eB));
+          RCP<Vector> mueluX = rcp(new Xpetra::EpetraVectorT<int,Node>(eX));
+          RCP<Vector> mueluB = rcp(new Xpetra::EpetraVectorT<int,Node>(eB));
           // Print relative residual norm
-          Teuchos::ScalarTraits<SC>::magnitudeType residualNorms2 = Utils::ResidualNorm(*A, *mueluX, *mueluB)[0];
+          Teuchos::ScalarTraits<SC>::magnitudeType residualNorms2 = Utilities::ResidualNorm(*A, *mueluX, *mueluB)[0];
           if (comm->getRank() == 0)
             std::cout << "||Residual|| = " << residualNorms2 << std::endl;
         }
 
         // TODO: AMG as a preconditioner (AZ_cg)
       }
-#endif // HAVE_MUELU_AZTECOO     
+#endif // HAVE_MUELU_AZTECOO
     } // if (translatedmuelu)
-    
+
 #if defined(HAVE_MUELU_ML) && defined(HAVE_MUELU_EPETRA)
     if (ml) {
 
@@ -440,10 +452,10 @@ int main(int argc, char *argv[]) {
       solver.Iterate(nIts, 1e-10);
 
       { //TODO: simplify this
-        RCP<Vector> mueluX = rcp(new Xpetra::EpetraVector(eX));
-        RCP<Vector> mueluB = rcp(new Xpetra::EpetraVector(eB));
+        RCP<Vector> mueluX = rcp(new Xpetra::EpetraVectorT<int,Node>(eX));
+        RCP<Vector> mueluB = rcp(new Xpetra::EpetraVectorT<int,Node>(eB));
         // Print relative residual norm
-        Teuchos::ScalarTraits<SC>::magnitudeType residualNorms = Utils::ResidualNorm(*A, *mueluX, *mueluB)[0];
+        Teuchos::ScalarTraits<SC>::magnitudeType residualNorms = Utilities::ResidualNorm(*A, *mueluX, *mueluB)[0];
         if (comm->getRank() == 0)
           std::cout << "||Residual|| = " << residualNorms << std::endl;
       }
