@@ -114,8 +114,6 @@
 #include "MueLu_AmalgamationFactory.hpp"
 #include "MueLu_AggregationExportFactory.hpp"
 
-#include "MueLu_UseDefaultTypes.hpp"
-
 #include <Epetra_LinearProblem.h>
 #include <AztecOO.h>
 
@@ -129,6 +127,13 @@
 
 
 int main(int argc, char *argv[]) {
+#if defined(HAVE_MUELU_SERIAL) && defined(HAVE_MUELU_EPETRA)
+  typedef double Scalar;
+  typedef int LocalOrdinal;
+  typedef int GlobalOrdinal;
+  typedef LocalOrdinal LO;
+  typedef GlobalOrdinal GO;
+  typedef Kokkos::Compat::KokkosSerialWrapperNode Node;
 #include "MueLu_UseShortNames.hpp"
 
   using Teuchos::RCP;
@@ -136,9 +141,6 @@ int main(int argc, char *argv[]) {
   using namespace MueLuTests;
   using namespace Teuchos;
 
-  typedef Xpetra::StridedMap<int,int>        StridedMap;
-  typedef Xpetra::StridedMapFactory<int,int> StridedMapFactory;
-
   oblackholestream blackhole;
   GlobalMPISession mpiSession(&argc,&argv,&blackhole);
   //
@@ -220,10 +222,10 @@ int main(int argc, char *argv[]) {
   /////////////////////////////////////// transform Epetra objects to Xpetra (needed for MueLu)
 
   // build Xpetra objects from Epetra_CrsMatrix objects
-  RCP<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > xA11 = rcp(new Xpetra::EpetraCrsMatrix(A11));
-  RCP<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > xA12 = rcp(new Xpetra::EpetraCrsMatrix(A12));
-  RCP<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > xA21 = rcp(new Xpetra::EpetraCrsMatrix(A21));
-  RCP<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > xA22 = rcp(new Xpetra::EpetraCrsMatrix(A22));
+  RCP<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > xA11 = rcp(new Xpetra::EpetraCrsMatrixT<GlobalOrdinal,Node>(A11));
+  RCP<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > xA12 = rcp(new Xpetra::EpetraCrsMatrixT<GlobalOrdinal,Node>(A12));
+  RCP<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > xA21 = rcp(new Xpetra::EpetraCrsMatrixT<GlobalOrdinal,Node>(A21));
+  RCP<Xpetra::CrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > xA22 = rcp(new Xpetra::EpetraCrsMatrixT<GlobalOrdinal,Node>(A22));
 
   /////////////////////////////////////// generate MapExtractor object
 
@@ -231,11 +233,11 @@ int main(int argc, char *argv[]) {
   xmaps.push_back(xstridedvelmap);
   xmaps.push_back(xstridedpremap);
 
-  RCP<const Xpetra::MapExtractor<Scalar,LocalOrdinal,GlobalOrdinal,Node> > map_extractor = Xpetra::MapExtractorFactory<Scalar,LocalOrdinal,GlobalOrdinal>::Build(xstridedfullmap,xmaps);
+  RCP<const Xpetra::MapExtractor<Scalar,LocalOrdinal,GlobalOrdinal,Node> > map_extractor = Xpetra::MapExtractorFactory<Scalar,LocalOrdinal,GlobalOrdinal,Node>::Build(xstridedfullmap,xmaps);
 
   /////////////////////////////////////// build blocked transfer operator
   // using the map extractor
-  RCP<Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > bOp = rcp(new Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal>(map_extractor,map_extractor,10));
+  RCP<Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node> > bOp = rcp(new Xpetra::BlockedCrsMatrix<Scalar,LocalOrdinal,GlobalOrdinal,Node>(map_extractor,map_extractor,10));
   bOp->setMatrix(0,0,xA11);
   bOp->setMatrix(0,1,xA12);
   bOp->setMatrix(1,0,xA21);
@@ -548,4 +550,8 @@ int main(int argc, char *argv[]) {
   }
 
   return EXIT_SUCCESS;
+#else
+  std::cout << "Epetra needs Serial node. Please recompile MueLu with the Serial node enabled." << std::endl;
+  return EXIT_SUCCESS;
+#endif // #if defined(HAVE_MUELU_SERIAL) && defined(HAVE_MUELU_EPETRA)
 }
