@@ -90,6 +90,8 @@
 #include "Tpetra_Experimental_BlockCrsMatrix.hpp"
 #endif
 
+#include <MueLu_TestHelpers_Common.hpp>
+
 namespace MueLuTests {
   using Teuchos::RCP;
   using Teuchos::rcp;
@@ -156,7 +158,7 @@ namespace MueLuTests {
         if (lib == Xpetra::NotSpecified)
           lib = TestHelpers::Parameters::getLib();
 
-        int nx,ny,nz; //global_size_t
+        GO nx,ny,nz;
         nx = ny = nz = 5;
         nx = matrixList.get("nx",nx);
         ny = matrixList.get("ny",ny);
@@ -301,7 +303,7 @@ namespace MueLuTests {
 
       // Create a 1D Poisson matrix with the specified number of rows
       // nx: global number of rows
-      static RCP<Matrix> Build1DPoisson(int nx, Xpetra::UnderlyingLib lib=Xpetra::NotSpecified) { //global_size_t
+      static RCP<Matrix> Build1DPoisson(GO nx, Xpetra::UnderlyingLib lib=Xpetra::NotSpecified) { //global_size_t
         Teuchos::ParameterList matrixList;
         matrixList.set("nx", nx);
         matrixList.set("matrixType","Laplace1D");
@@ -312,7 +314,7 @@ namespace MueLuTests {
       // Create a 2D Poisson matrix with the specified number of rows
       // nx: global number of rows
       // ny: global number of rows
-      static RCP<Matrix> Build2DPoisson(int nx, int ny=-1, Xpetra::UnderlyingLib lib=Xpetra::NotSpecified) { //global_size_t
+      static RCP<Matrix> Build2DPoisson(GO nx, GO ny=-1, Xpetra::UnderlyingLib lib=Xpetra::NotSpecified) { //global_size_t
         Teuchos::ParameterList matrixList;
         if (ny==-1) ny=nx;
         matrixList.set("nx", nx);
@@ -332,14 +334,16 @@ namespace MueLuTests {
           lib = TestHelpers::Parameters::getLib();
 
         // This only works for Tpetra
-        if(lib!=Xpetra::UseTpetra) return Op;
+        if (lib!=Xpetra::UseTpetra) return Op;
+
+#if defined(HAVE_MUELU_TPETRA)
+#ifdef HAVE_MUELU_BROKEN_TESTS
+        // Thanks for the code, Travis!
 
         // Make the graph
         RCP<Matrix> FirstMatrix = BuildMatrix(matrixList,lib);
         RCP<const Xpetra::CrsGraph<LO,GO,NO> > Graph = FirstMatrix->getCrsGraph();
 
-#if defined(HAVE_MUELU_TPETRA)
-        // Thanks for the code, Travis!
         int blocksize = 3;
         RCP<const Xpetra::TpetraCrsGraph<LO,GO,NO> > TGraph = rcp_dynamic_cast<const Xpetra::TpetraCrsGraph<LO,GO,NO> >(Graph);
         RCP<const Tpetra::CrsGraph<LO,GO,NO> > TTGraph = TGraph->getTpetra_CrsGraph();
@@ -364,10 +368,10 @@ namespace MueLuTests {
           lclColInds[0] = lclRowInd;
           bcrsmatrix->replaceLocalValues(lclRowInd, lclColInds.getRawPtr(), &basematrix[0], 1);
         }
-        bcrsmatrix->computeDiagonalGraph(); // Needs to get done to smooth for some reason
 
         RCP<Xpetra::CrsMatrix<SC,LO,GO,NO> > temp = rcp(new Xpetra::TpetraBlockCrsMatrix<SC,LO,GO,NO>(bcrsmatrix));
         Op = rcp(new Xpetra::CrsMatrixWrap<SC,LO,GO,NO>(temp));
+#endif
 #endif
         return Op;
      } // BuildMatrix()
@@ -402,15 +406,14 @@ namespace MueLuTests {
 #endif
       }
 
-#if defined(HAVE_MUELU_EPETRA) && defined(HAVE_MUELU_IFPACK)
       static RCP<SmootherPrototype> createSmootherPrototype(const std::string& type="Gauss-Seidel", LO sweeps=1) {
+        std::string ifpackType = "RELAXATION";
         Teuchos::ParameterList  ifpackList;
         ifpackList.set("relaxation: type", type);
         ifpackList.set("relaxation: sweeps", (LO) sweeps);
         ifpackList.set("relaxation: damping factor", (SC) 1.0);
-        return rcp( new IfpackSmoother("point relaxation stand-alone",ifpackList) );
+        return Teuchos::rcp( new TrilinosSmoother(ifpackType, ifpackList) );
       }
-#endif
 
     }; // class Factory
 
@@ -426,7 +429,10 @@ namespace MueLuTests {
 
 // Macro to skip a test when UnderlyingLib==Epetra or Tpetra
 #define MUELU_TEST_ONLY_FOR(UnderlyingLib) \
-  if (TestHelpers::Parameters::getLib() == UnderlyingLib)
+  if (TestHelpers::Parameters::getLib() != UnderlyingLib) { \
+    out << "Skipping test for " << ((TestHelpers::Parameters::getLib()==Xpetra::UseEpetra) ? "Epetra" : "Tpetra") << std::endl; \
+    return; \
+  }
 
 // Macro to skip a test when Epetra is used with Ordinal != int
 #define MUELU_TEST_EPETRA_ONLY_FOR_INT(LocalOrdinal, GlobalOrdinal) \
@@ -437,11 +443,6 @@ namespace MueLuTests {
   if (!(TestHelpers::Parameters::getLib() == Xpetra::UseEpetra && Teuchos::ScalarTraits<Scalar>::name() != string("double"))) \
     MUELU_TEST_EPETRA_ONLY_FOR_INT(LocalOrdinal, GlobalOrdinal)
 
-
-
-
-
-
 //
 
 //TODO: add directly to Teuchos ?
