@@ -43,26 +43,24 @@
 // ***********************************************************************
 //
 // @HEADER
-#include "Teuchos_UnitTestHarness.hpp"
-#include "MueLu_TestHelpers.hpp"
-#include "MueLu_Version.hpp"
+#include <Teuchos_UnitTestHarness.hpp>
+#include <MueLu_TestHelpers.hpp>
+#include <MueLu_Version.hpp>
 
-#include "MueLu_UseDefaultTypes.hpp"
+#include <MueLu_ZoltanInterface.hpp>
 
-#include "MueLu_ZoltanInterface.hpp"
+#include <Galeri_XpetraUtils.hpp>
 
-#include "Galeri_XpetraUtils.hpp"
-
-#include "Xpetra_MultiVectorFactory.hpp"
-#include "Xpetra_ExportFactory.hpp"
+#include <Xpetra_MultiVectorFactory.hpp>
+#include <Xpetra_ExportFactory.hpp>
 
 namespace MueLuTests {
 
-#include "MueLu_UseShortNames.hpp"
-
-  TEUCHOS_UNIT_TEST(Zoltan, Constructor)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(Zoltan, Constructor, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
-
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
     out << "version: " << MueLu::Version() << std::endl;
 
     RCP<const Teuchos::Comm<int> > comm = TestHelpers::Parameters::getDefaultComm();
@@ -71,10 +69,11 @@ namespace MueLuTests {
 
   } //Constructor
 
-  TEUCHOS_UNIT_TEST(Zoltan, Build)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_DECL(Zoltan, Build, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
-    typedef Teuchos::ScalarTraits<Scalar> ST;
-
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
     out << "version: " << MueLu::Version() << std::endl;
     out << std::endl;
     out << "This tests that the partitioning produced by Zoltan is \"reasonable\" for a matrix" << std::endl;
@@ -82,6 +81,7 @@ namespace MueLuTests {
     out << "for up to 5 processors.  The results are the number of nonzeros in the local matrix" << std::endl;
     out << "once the Zoltan repartitioning has been applied." << std::endl;
     out << "The results can be viewed in Paraview by enabling code guarded by the macro MUELU_VISUALIZE_REPARTITIONING" << std::endl;
+    typedef Teuchos::ScalarTraits<Scalar> ST;
 
     RCP<const Teuchos::Comm<int> > comm = TestHelpers::Parameters::getDefaultComm();
 
@@ -95,13 +95,13 @@ namespace MueLuTests {
     Level level;
     RCP<FactoryManagerBase> factoryHandler = rcp(new FactoryManager());
     level.SetFactoryManager(factoryHandler);
-    int nx=7;
-    int ny=nx;
-    GO numGlobalElements = nx*ny;
+    GO nx=7;
+    GO ny=nx;
+    Xpetra::global_size_t numGlobalElements = nx*ny;
     size_t maxEntriesPerRow=30;
 
     // Populate CrsMatrix with random number of entries (up to maxEntriesPerRow) per row.
-    RCP<const Map> map = MapFactory::createUniformContigMap(TestHelpers::Parameters::getLib(), numGlobalElements, comm);
+    RCP<const Map> map = MapFactory::Build(TestHelpers::Parameters::getLib(), numGlobalElements, 0/*indexBase*/, comm);
     const size_t numMyElements = map->getNodeNumElements();
     Teuchos::ArrayView<const GlobalOrdinal> myGlobalElements = map->getNodeElementList();
     RCP<Matrix> A = rcp(new CrsMatrixWrap(map, 1)); // Force underlying linear algebra library to allocate more
@@ -112,13 +112,16 @@ namespace MueLuTests {
     ST::seedrandom(666*comm->getRank());
     RCP<Xpetra::Vector<LO,LO,GO,NO> > entriesPerRow = Xpetra::VectorFactory<LO,LO,GO,NO>::Build(map,false);
     Teuchos::ArrayRCP<LO> eprData = entriesPerRow->getDataNonConst(0);
-    for (Teuchos::ArrayRCP<LO>::iterator i=eprData.begin(); i!=eprData.end(); ++i) {
-      *i = (LO)(std::floor(((ST::random()+1)*0.5*maxEntriesPerRow)+1));
+    for (typename Teuchos::ArrayRCP<LO>::iterator i=eprData.begin(); i!=eprData.end(); ++i) {
+      *i = (LO)(std::floor(((Teuchos::ScalarTraits<double>::random()+1)*0.5*maxEntriesPerRow)+1));
     }
 
     RCP<Teuchos::FancyOStream> fos = Teuchos::fancyOStream(Teuchos::rcpFromRef(std::cout));
     fos->setOutputToRootOnly(-1);
 
+    GO zero = Teuchos::OrdinalTraits<GO>::zero();
+    GO one = Teuchos::OrdinalTraits<GO>::one();
+
     Teuchos::Array<Scalar> vals(maxEntriesPerRow);
     Teuchos::Array<GO> cols(maxEntriesPerRow);
     for (size_t i = 0; i < numMyElements; ++i) {
@@ -127,7 +130,7 @@ namespace MueLuTests {
       //stick in ones for values
       for (LO j=0; j< eprData[i]; ++j) vals[j] = ST::one();
       //figure out valid column indices
-      GO start = std::max(myGlobalElements[i]-eprData[i]+1,0);
+      GO start = std::max(myGlobalElements[i]-eprData[i]+one,zero);
       for (LO j=0; j< eprData[i]; ++j) cols[j] = start+j;
       A->insertGlobalValues(myGlobalElements[i], iv, av);
     }
@@ -140,10 +143,11 @@ namespace MueLuTests {
     Teuchos::ParameterList list;
     list.set("nx",nx);
     list.set("ny",ny);
-    RCP<MultiVector> XYZ = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("2D",rowMap,list);
+    typedef Xpetra::MultiVector<double, LocalOrdinal, GlobalOrdinal, Node> double_multivector_type;
+    RCP<double_multivector_type> XYZ = Galeri::Xpetra::Utils::CreateCartesianCoordinates<double,LO,GO,Map,double_multivector_type>("2D",rowMap,list);
     level.Set("Coordinates",XYZ);
 
-    LO numPartitions = comm->getSize();
+    GO numPartitions = comm->getSize();
     level.Set("number of partitions",numPartitions);
     RCP<ZoltanInterface> zoltan = rcp(new ZoltanInterface());
     //zoltan->SetNumberOfPartitions(numPartitions);
@@ -171,7 +175,7 @@ namespace MueLuTests {
 
     //For the local rows in each partition, tally up the number of nonzeros.  This is what
     //Zoltan should be load-balancing.
-    Teuchos::ArrayRCP<GO> lpvData = localPartsVec->getDataNonConst(0);
+    Teuchos::ArrayRCP<LO> lpvData = localPartsVec->getDataNonConst(0);
     Teuchos::ArrayRCP<const GO> decompData = decomposition->getData(0);
     for (size_t i=0; i<decomposition->getLocalLength();++i) {
       Teuchos::ArrayView<const LO> c;
@@ -249,8 +253,8 @@ namespace MueLuTests {
     //
     //Now write everything to a comma-separate list that ParaView can grok
     //
-    Teuchos::ArrayRCP<const Scalar> X = XYZ->getData(0);
-    Teuchos::ArrayRCP<const Scalar> Y = XYZ->getData(1);
+    Teuchos::ArrayRCP<const double> X = XYZ->getData(0);
+    Teuchos::ArrayRCP<const double> Y = XYZ->getData(1);
     Teuchos::ArrayRCP<const GO> D = decomposition->getData(0);
     RCP<std::ofstream> outFile;
     std::string fileName = "zoltanResults.csv";
@@ -291,11 +295,14 @@ namespace MueLuTests {
   } //Build
 
 #ifdef DISABLED // JG: FIXME: coordinates format
-  TEUCHOS_UNIT_TEST(Zoltan, Build3PDEs)
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Zoltan, Build3PDEs, Scalar, LocalOrdinal, GlobalOrdinal, Node)
   {
 
     typedef Teuchos::ScalarTraits<Scalar> ST;
 
+#   include <MueLu_UseShortNames.hpp>
+    MUELU_TESTING_SET_OSTREAM;
+    MUELU_TESTING_LIMIT_SCOPE(Scalar,GlobalOrdinal,Node);
     out << "version: " << MueLu::Version() << std::endl;
     out << std::endl;
     out << "This tests that the partitioning produced by Zoltan is \"reasonable\" for a matrix" << std::endl;
@@ -333,9 +340,9 @@ namespace MueLuTests {
       int nproc = comm->getSize();
       if (comm->getRank() < nproc-1) numMyNodes = numNodes / nproc;
       else numMyNodes = numNodes - (numNodes/nproc) * (nproc-1);
-      map = MapFactory::createContigMap(TestHelpers::Parameters::getLib(), numGlobalElements, numMyNodes*dofsPerNode, comm);
+      map = MapFactory::Build(TestHelpers::Parameters::getLib(), numGlobalElements, numMyNodes*dofsPerNode, 0/*indexBase*/, comm);
     } else {
-      map = MapFactory::createUniformContigMap(TestHelpers::Parameters::getLib(), numGlobalElements, comm);
+      map = MapFactory::Build(TestHelpers::Parameters::getLib(), numGlobalElements, 0/*indexBase*/, comm);
     }
 
     const size_t numMyElements = map->getNodeNumElements();
@@ -379,7 +386,7 @@ namespace MueLuTests {
     Teuchos::ParameterList list;
     list.set("nx",nx);
     list.set("ny",ny);
-    RCP<const Map> coalescedMap = MapFactory::createContigMap(TestHelpers::Parameters::getLib(), numGlobalElements/dofsPerNode, numMyNodes, comm);
+    RCP<const Map> coalescedMap = MapFactory::Build<NO>(TestHelpers::Parameters::getLib(), numGlobalElements/dofsPerNode, numMyNodes, 0/*indexBase*/, comm);
     RCP<MultiVector> XYZ = Galeri::Xpetra::Utils::CreateCartesianCoordinates<SC,LO,GO,Map,MultiVector>("2D",coalescedMap,list);
 
     // XYZ are the "coalesce" coordinates as it has been generated for 1 DOF/node and we are using them for 3 DOFS/node
@@ -539,8 +546,8 @@ namespace MueLuTests {
     //
     //Now write everything to a comma-separate list that ParaView can grok
     //
-    Teuchos::ArrayRCP<const Scalar> X = XYZ->getData(0);
-    Teuchos::ArrayRCP<const Scalar> Y = XYZ->getData(1);
+    Teuchos::ArrayRCP<const double> X = XYZ->getData(0);
+    Teuchos::ArrayRCP<const double> Y = XYZ->getData(1);
     Teuchos::ArrayRCP<const GO> D = decomposition->getData(0);
     RCP<std::ofstream> outFile;
     std::string fileName = "zoltanResults.csv";
@@ -587,5 +594,10 @@ namespace MueLuTests {
   } //Build3PDEs
 #endif // TMP
 
+#define MUELU_ETI_GROUP(SC,LO,GO,NO) \
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Zoltan,Constructor,SC,LO,GO,NO) \
+  TEUCHOS_UNIT_TEST_TEMPLATE_4_INSTANT(Zoltan,Build,SC,LO,GO,NO)
+
+#include <MueLu_ETI_4arg.hpp>
 
 }//namespace MueLuTests
