@@ -91,19 +91,22 @@
 #endif
 
 namespace MueLuTests {
-  using Teuchos::RCP;
-  using Teuchos::rcp;
-  using Teuchos::ArrayRCP;
-  using Teuchos::ArrayView;
   using Teuchos::arcp;
   using Teuchos::arcpFromArrayView;
-  using Teuchos::rcpFromRef;
-  using Teuchos::null;
   using Teuchos::arcp_reinterpret_cast;
   using Teuchos::Array;
+  using Teuchos::ArrayRCP;
+  using Teuchos::ArrayView;
+  using Teuchos::as;
+  using Teuchos::null;
+  using Teuchos::ParameterList;
+  using Teuchos::rcp;
+  using Teuchos::RCP;
   using Teuchos::rcp_dynamic_cast;
-  using Teuchos::rcp_implicit_cast;
   using Teuchos::rcpFromRef;
+  using Teuchos::rcp_implicit_cast;
+
+# include <MueLu_TestHelpers_Common_kokkos.hpp>
 
   namespace TestHelpers_kokkos {
 
@@ -202,41 +205,37 @@ namespace MueLuTests {
         return BuildMatrix(matrixList,lib);
       }
 
-#if 0
       // Create a tridiagonal matrix (stencil = [b,a,c]) with the specified number of rows
-      // dofMap: row map of matrix
-      static RCP<Matrix> BuildTridiag(RCP<const Map> dofMap, Scalar a, Scalar b, Scalar c, Xpetra::UnderlyingLib lib=Xpetra::NotSpecified) { //global_size_t
-
+      static RCP<Matrix> BuildTridiag(RCP<const Map> rowMap, SC a, SC b, SC c, Xpetra::UnderlyingLib lib = Xpetra::NotSpecified) {
         if (lib == Xpetra::NotSpecified)
           lib = TestHelpers_kokkos::Parameters::getLib();
 
         RCP<const Teuchos::Comm<int> > comm = Parameters::getDefaultComm();
 
-        Teuchos::RCP<Matrix> mtx = Xpetra::MatrixFactory<Scalar, LocalOrdinal, GlobalOrdinal, Node>::Build(dofMap, 3);
+        RCP<Matrix> mtx = MatrixFactory::Build(rowMap, 3);
 
-        LocalOrdinal NumMyElements = dofMap->getNodeNumElements();
-        Teuchos::ArrayView<const GlobalOrdinal> MyGlobalElements = dofMap->getNodeElementList();
-        GlobalOrdinal indexBase = dofMap->getIndexBase();
+        ArrayView<const GO> MyGlobalElements = rowMap->getNodeElementList();
+        GO indexBase = rowMap->getIndexBase();
 
-        GlobalOrdinal NumEntries;
-        LocalOrdinal  nnz = 3;
-        std::vector<Scalar>        Values(nnz);
-        std::vector<GlobalOrdinal> Indices(nnz);
+        GO NumEntries;
+        LO nnz = 3;
+        std::vector<SC> Values(nnz);
+        std::vector<GO> Indices(nnz);
 
         // access information from strided block map
         std::vector<size_t> strInfo = std::vector<size_t>();
         size_t blockSize = 1;
-        LocalOrdinal blockId = -1;
-        GlobalOrdinal offset = 0;
+        LO blockId = -1;
+        GO offset = 0;
 
-        Teuchos::RCP<const StridedMap> strdofMap = Teuchos::rcp_dynamic_cast<const StridedMap>(dofMap);
-        if(strdofMap != Teuchos::null) {
-          strInfo = strdofMap->getStridingData();
-          blockSize = strdofMap->getFixedBlockSize();
-          blockId = strdofMap->getStridedBlockId();
-          offset = strdofMap->getOffset();
+        RCP<const StridedMap> strrowMap = rcp_dynamic_cast<const StridedMap>(rowMap);
+        if (strrowMap != Teuchos::null) {
+          strInfo   = strrowMap->getStridingData();
+          blockSize = strrowMap->getFixedBlockSize();
+          blockId   = strrowMap->getStridedBlockId();
+          offset    = strrowMap->getOffset();
           TEUCHOS_TEST_FOR_EXCEPTION(blockId > -1 && strInfo[blockId]==1, MueLu::Exceptions::RuntimeError,
-                                             "MueLu::TestHelpers_kokkos::BuildTridiag: strInfo block size must be > 1.");
+                                     "MueLu::TestHelpers_kokkos::BuildTridiag: strInfo block size must be > 1.");
           // todo: write one more special case for a row being first and last bock row
         } else {
           // no striding information. emulate block matrix
@@ -244,18 +243,18 @@ namespace MueLuTests {
           strInfo.push_back(blockSize); // default block size = 1
         }
 
-        GlobalOrdinal rrmax = (dofMap->getMaxAllGlobalIndex()-offset-indexBase) / blockSize;
+        GO rrmax = (rowMap->getMaxAllGlobalIndex()-offset-indexBase) / blockSize;
 
         // loop over all rows
-        for (LocalOrdinal i = 0; i < NumMyElements; i++) {
-
-          GlobalOrdinal rr = (MyGlobalElements[i]-offset-indexBase) / blockSize + indexBase;  // node index
+        LO numMyElements = rowMap->getNodeNumElements();
+        for (LO i = 0; i < numMyElements; i++) {
+          GO rr = (MyGlobalElements[i]-offset-indexBase) / blockSize + indexBase;  // node index
 
           // distinguish 5 different cases
 
-          GlobalOrdinal blockOffset = 0;
-          for (LocalOrdinal k=0; k<blockId; k++)
-            blockOffset += Teuchos::as<GlobalOrdinal>(strInfo[k]);
+          GO blockOffset = 0;
+          for (LO k = 0; k < blockId; k++)
+            blockOffset += Teuchos::as<GO>(strInfo[k]);
 
           if (MyGlobalElements[i] == blockOffset + offset + indexBase) {
             // very first row
@@ -264,6 +263,7 @@ namespace MueLuTests {
             Indices[1] = MyGlobalElements[i] + 1;
             Values [1] = c;
             NumEntries = 2;
+
           } else if (MyGlobalElements[i] == rrmax * Teuchos::as<GO>(blockSize) + blockOffset + Teuchos::as<GO>(strInfo[blockId]) - 1 + offset + indexBase) {
             // very last row
             Indices[0] = MyGlobalElements[i] - 1;
@@ -271,6 +271,7 @@ namespace MueLuTests {
             Indices[1] = MyGlobalElements[i];
             Values [1] = a;
             NumEntries = 2;
+
           } else if (MyGlobalElements[i] == rr * Teuchos::as<GO>(blockSize) + blockOffset + Teuchos::as<GO>(strInfo[blockId]) - 1 + offset + indexBase) {
             // last row in current node block
             Indices[0] = MyGlobalElements[i] - 1;
@@ -280,6 +281,7 @@ namespace MueLuTests {
             Indices[2] = (rr+1)*blockSize + blockOffset + offset + indexBase;
             Values [2] = c;
             NumEntries = 3;
+
           } else if (MyGlobalElements[i] == rr * Teuchos::as<GO>(blockSize) + blockOffset + offset + indexBase) {
             // first row in current node block
             Indices[0] = (rr-1)*blockSize + blockOffset + strInfo[blockId] - 1 + offset + indexBase;
@@ -289,6 +291,7 @@ namespace MueLuTests {
             Indices[2] = MyGlobalElements[i] + 1;
             Values [2] = c;
             NumEntries = 3;
+
           } else {
             // usual row entries in block rows
             Indices[0] = MyGlobalElements[i] - 1;
@@ -309,17 +312,15 @@ namespace MueLuTests {
 
           // put the off-diagonal entries
           // Xpetra wants ArrayViews (sigh)
-          Teuchos::ArrayView<Scalar>        av(&Values [0], NumEntries);
-          Teuchos::ArrayView<GlobalOrdinal> iv(&Indices[0], NumEntries);
+          ArrayView<SC> av(&Values [0], NumEntries);
+          ArrayView<GO> iv(&Indices[0], NumEntries);
           mtx->insertGlobalValues(MyGlobalElements[i], iv, av);
         }
 
         mtx->fillComplete();
 
         return mtx;
-      } // BuildTridiag()
-#endif
-
+      }
 
      // Create a matrix as specified by parameter list options
      static RCP<Matrix> BuildBlockMatrix(Teuchos::ParameterList &matrixList, Xpetra::UnderlyingLib lib=Xpetra::NotSpecified) {
@@ -362,7 +363,6 @@ namespace MueLuTests {
           lclColInds[0] = lclRowInd;
           bcrsmatrix->replaceLocalValues(lclRowInd, lclColInds.getRawPtr(), &basematrix[0], 1);
         }
-        bcrsmatrix->computeDiagonalGraph(); // Needs to get done to smooth for some reason
 
         RCP<Xpetra::CrsMatrix<SC,LO,GO,NO> > temp = rcp(new Xpetra::TpetraBlockCrsMatrix<SC,LO,GO,NO>(bcrsmatrix));
         Op = rcp(new Xpetra::CrsMatrixWrap<SC,LO,GO,NO>(temp));
@@ -424,7 +424,10 @@ namespace MueLuTests {
 
 // Macro to skip a test when UnderlyingLib==Epetra or Tpetra
 #define MUELU_TEST_ONLY_FOR(UnderlyingLib) \
-  if (TestHelpers_kokkos::Parameters::getLib() == UnderlyingLib)
+  if (TestHelpers_kokkos::Parameters::getLib() != UnderlyingLib) { \
+    out << "Skipping test for " << ((TestHelpers_kokkos::Parameters::getLib()==Xpetra::UseEpetra) ? "Epetra" : "Tpetra") << std::endl; \
+    return; \
+  }
 
 // Macro to skip a test when Epetra is used with Ordinal != int
 #define MUELU_TEST_EPETRA_ONLY_FOR_INT(LocalOrdinal, GlobalOrdinal) \
