@@ -73,17 +73,17 @@
 
 #include "Piro_InvertMassMatrixDecorator.hpp"
 
-#ifdef Piro_ENABLE_Ifpack2
+#ifdef HAVE_PIRO_IFPACK2
 #include "Thyra_Ifpack2PreconditionerFactory.hpp"
 #include "Tpetra_CrsMatrix.hpp"
 #endif
 
-#ifdef Piro_ENABLE_MueLu
+#ifdef HAVE_PIRO_MUELU
 #include <Thyra_MueLuPreconditionerFactory.hpp>
 #include "Stratimikos_MueLuHelpers.hpp"
 #endif
 
-#ifdef Piro_ENABLE_NOX
+#ifdef HAVE_PIRO_NOX
 #  include "Thyra_NonlinearSolver_NOX.hpp"
 #endif
 
@@ -91,16 +91,25 @@
 #include <stdexcept>
 #include <iostream>
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::RythmosSolver() :
+#else
 template <typename Scalar>
 Piro::RythmosSolver<Scalar>::RythmosSolver() :
+#endif
   out(Teuchos::VerboseObjectBase::getDefaultOStream()),
   isInitialized(false)
 {
 }
 
-
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::RythmosSolver(
+#else
 template <typename Scalar>
 Piro::RythmosSolver<Scalar>::RythmosSolver(
+#endif
     const Teuchos::RCP<Teuchos::ParameterList> &appParams,
     const Teuchos::RCP<Thyra::ModelEvaluator<Scalar> > &in_model,
     const Teuchos::RCP<Rythmos::IntegrationObserverBase<Scalar> > &observer) :
@@ -110,8 +119,13 @@ Piro::RythmosSolver<Scalar>::RythmosSolver(
   initialize(appParams,in_model,observer);
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+void Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::initialize(
+#else
 template <typename Scalar>
 void Piro::RythmosSolver<Scalar>::initialize(
+#endif
     const Teuchos::RCP<Teuchos::ParameterList> &appParams,
     const Teuchos::RCP< Thyra::ModelEvaluator<Scalar> > &in_model,
     const Teuchos::RCP<Rythmos::IntegrationObserverBase<Scalar> > &observer)
@@ -170,7 +184,7 @@ void Piro::RythmosSolver<Scalar>::initialize(
     fwdTimeStepSolver = rythmosTimeStepSolver;
   }
   else if (rythmosPL->get<std::string>("Nonlinear Solver Type") == "NOX") {
-#ifdef Piro_ENABLE_NOX
+#ifdef HAVE_PIRO_NOX
     Teuchos::RCP<Thyra::NOXNonlinearSolver> nox_solver =  Teuchos::rcp(new Thyra::NOXNonlinearSolver);
     Teuchos::RCP<Teuchos::ParameterList> nox_params = Teuchos::rcp(new Teuchos::ParameterList);
     *nox_params = appParams->sublist("NOX");
@@ -206,7 +220,7 @@ void Piro::RythmosSolver<Scalar>::initialize(
   }
   else {
     // first (before failing) check to see if the user has added stepper factory
-    typename std::map<std::string,Teuchos::RCP<RythmosStepperFactory<Scalar> > >::const_iterator
+    typename std::map<std::string,Teuchos::RCP<Piro::RythmosStepperFactory<Scalar> > >::const_iterator
         stepFactItr = stepperFactories.find(stepperType);
     if(stepFactItr!=stepperFactories.end()) {
       // the user has added it, hot dog lets build a new stepper!
@@ -254,7 +268,7 @@ void Piro::RythmosSolver<Scalar>::initialize(
       } 
     else {
        // first (before failing) check to see if the user has added step control factory
-       typename std::map<std::string,Teuchos::RCP<RythmosStepControlFactory<Scalar> > >::const_iterator
+       typename std::map<std::string,Teuchos::RCP<Piro::RythmosStepControlFactory<Scalar> > >::const_iterator
            stepControlFactItr = stepControlFactories.find(step_control_strategy);
       if (stepControlFactItr != stepControlFactories.end())
          {
@@ -327,13 +341,21 @@ void Piro::RythmosSolver<Scalar>::initialize(
      //
      Stratimikos::DefaultLinearSolverBuilder linearSolverBuilder;
 
-#ifdef Piro_ENABLE_Ifpack2
+#ifdef HAVE_PIRO_IFPACK2
      typedef Thyra::PreconditionerFactoryBase<double> Base;
+#ifdef ALBANY_BUILD
+     typedef Thyra::Ifpack2PreconditionerFactory<Tpetra::CrsMatrix<double, LocalOrdinal, GlobalOrdinal, Node> > Impl;
+#else
      typedef Thyra::Ifpack2PreconditionerFactory<Tpetra::CrsMatrix<double> > Impl;
+#endif
      linearSolverBuilder.setPreconditioningStrategyFactory(Teuchos::abstractFactoryStd<Base, Impl>(), "Ifpack2");
 #endif
-#ifdef Piro_ENABLE_MueLu
+#ifdef HAVE_PIRO_MUELU
+#ifdef ALBANY_BUILD
+     Stratimikos::enableMueLu<LocalOrdinal, GlobalOrdinal, Node>(linearSolverBuilder);
+#else
      Stratimikos::enableMueLu(linearSolverBuilder);
+#endif
 #endif
 
      linearSolverBuilder.setParameterList(sublist(rythmosSolverPL, "Stratimikos", true));
@@ -399,9 +421,13 @@ else {
   isInitialized = true;
 }
 
-
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::RythmosSolver(
+#else
 template <typename Scalar>
 Piro::RythmosSolver<Scalar>::RythmosSolver(
+#endif
     const Teuchos::RCP<Rythmos::DefaultIntegrator<Scalar> > &stateIntegrator,
     const Teuchos::RCP<Rythmos::StepperBase<Scalar> > &stateStepper,
     const Teuchos::RCP<Thyra::NonlinearSolverBase<Scalar> > &timeStepSolver,
@@ -427,8 +453,13 @@ Piro::RythmosSolver<Scalar>::RythmosSolver(
   }
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::RythmosSolver(
+#else
 template <typename Scalar>
 Piro::RythmosSolver<Scalar>::RythmosSolver(
+#endif
     const Teuchos::RCP<Rythmos::DefaultIntegrator<Scalar> > &stateIntegrator,
     const Teuchos::RCP<Rythmos::StepperBase<Scalar> > &stateStepper,
     const Teuchos::RCP<Thyra::NonlinearSolverBase<Scalar> > &timeStepSolver,
@@ -455,17 +486,28 @@ Piro::RythmosSolver<Scalar>::RythmosSolver(
   }
 }
 
-
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Teuchos::RCP<const Rythmos::IntegratorBase<Scalar> >
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::getRythmosIntegrator() const
+#else
 template <typename Scalar>
 Teuchos::RCP<const Rythmos::IntegratorBase<Scalar> >
 Piro::RythmosSolver<Scalar>::getRythmosIntegrator() const
+#endif
 {
   return fwdStateIntegrator;
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Teuchos::RCP<const Thyra::VectorSpaceBase<Scalar> >
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::get_p_space(int l) const
+#else
 template<typename Scalar>
 Teuchos::RCP<const Thyra::VectorSpaceBase<Scalar> >
 Piro::RythmosSolver<Scalar>::get_p_space(int l) const
+#endif
 {
   TEUCHOS_TEST_FOR_EXCEPTION(
       l >= num_p || l < 0,
@@ -478,9 +520,15 @@ Piro::RythmosSolver<Scalar>::get_p_space(int l) const
   return model->get_p_space(l);
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Teuchos::RCP<const Thyra::VectorSpaceBase<Scalar> >
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::get_g_space(int j) const
+#else
 template<typename Scalar>
 Teuchos::RCP<const Thyra::VectorSpaceBase<Scalar> >
 Piro::RythmosSolver<Scalar>::get_g_space(int j) const
+#endif
 {
   TEUCHOS_TEST_FOR_EXCEPTION(
       j > num_g || j < 0,
@@ -498,9 +546,15 @@ Piro::RythmosSolver<Scalar>::get_g_space(int j) const
   }
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Thyra::ModelEvaluatorBase::InArgs<Scalar>
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::getNominalValues() const
+#else
 template<typename Scalar>
 Thyra::ModelEvaluatorBase::InArgs<Scalar>
 Piro::RythmosSolver<Scalar>::getNominalValues() const
+#endif
 {
   Thyra::ModelEvaluatorBase::InArgs<Scalar> result = this->createInArgs();
   const Thyra::ModelEvaluatorBase::InArgs<Scalar> modelNominalValues = model->getNominalValues();
@@ -510,8 +564,15 @@ Piro::RythmosSolver<Scalar>::getNominalValues() const
   return result;
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Thyra::ModelEvaluatorBase::InArgs<Scalar> 
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::createInArgs() const
+#else
 template <typename Scalar>
-Thyra::ModelEvaluatorBase::InArgs<Scalar> Piro::RythmosSolver<Scalar>::createInArgs() const
+Thyra::ModelEvaluatorBase::InArgs<Scalar> 
+Piro::RythmosSolver<Scalar>::createInArgs() const
+#endif
 {
   Thyra::ModelEvaluatorBase::InArgsSetup<Scalar> inArgs;
   inArgs.setModelEvalDescription(this->description());
@@ -519,8 +580,15 @@ Thyra::ModelEvaluatorBase::InArgs<Scalar> Piro::RythmosSolver<Scalar>::createInA
   return inArgs;
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Thyra::ModelEvaluatorBase::OutArgs<Scalar> 
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::createOutArgsImpl() const
+#else
 template <typename Scalar>
-Thyra::ModelEvaluatorBase::OutArgs<Scalar> Piro::RythmosSolver<Scalar>::createOutArgsImpl() const
+Thyra::ModelEvaluatorBase::OutArgs<Scalar> 
+Piro::RythmosSolver<Scalar>::createOutArgsImpl() const
+#endif
 {
   Thyra::ModelEvaluatorBase::OutArgsSetup<Scalar> outArgs;
   outArgs.setModelEvalDescription(this->description());
@@ -590,8 +658,13 @@ Thyra::ModelEvaluatorBase::OutArgs<Scalar> Piro::RythmosSolver<Scalar>::createOu
   return outArgs;
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+void Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::evalModelImpl(
+#else
 template <typename Scalar>
 void Piro::RythmosSolver<Scalar>::evalModelImpl(
+#endif
     const Thyra::ModelEvaluatorBase::InArgs<Scalar>& inArgs,
     const Thyra::ModelEvaluatorBase::OutArgs<Scalar>& outArgs) const
 {
@@ -909,9 +982,15 @@ void Piro::RythmosSolver<Scalar>::evalModelImpl(
   }
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Teuchos::RCP<Thyra::LinearOpBase<Scalar> >
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::create_DgDp_op_impl(int j, int l) const
+#else
 template <typename Scalar>
 Teuchos::RCP<Thyra::LinearOpBase<Scalar> >
 Piro::RythmosSolver<Scalar>::create_DgDp_op_impl(int j, int l) const
+#endif
 {
   TEUCHOS_ASSERT(j != num_g);
   const Teuchos::Array<Teuchos::RCP<const Thyra::LinearOpBase<Scalar> > > dummy =
@@ -919,9 +998,15 @@ Piro::RythmosSolver<Scalar>::create_DgDp_op_impl(int j, int l) const
   return Teuchos::rcp(new Thyra::DefaultAddedLinearOp<Scalar>(dummy));
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Teuchos::RCP<const Teuchos::ParameterList>
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::getValidRythmosParameters() const
+#else
 template <typename Scalar>
 Teuchos::RCP<const Teuchos::ParameterList>
 Piro::RythmosSolver<Scalar>::getValidRythmosParameters() const
+#endif
 {
   Teuchos::RCP<Teuchos::ParameterList> validPL =
      Teuchos::rcp(new Teuchos::ParameterList("ValidRythmosParams"));
@@ -961,9 +1046,15 @@ Piro::RythmosSolver<Scalar>::getValidRythmosParameters() const
   return validPL;
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Teuchos::RCP<const Teuchos::ParameterList>
+Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::getValidRythmosSolverParameters() const
+#else
 template <typename Scalar>
 Teuchos::RCP<const Teuchos::ParameterList>
 Piro::RythmosSolver<Scalar>::getValidRythmosSolverParameters() const
+#endif
 {
   Teuchos::RCP<Teuchos::ParameterList> validPL =
     Teuchos::rcp(new Teuchos::ParameterList("ValidRythmosSolverParams"));;
@@ -976,23 +1067,38 @@ Piro::RythmosSolver<Scalar>::getValidRythmosSolverParameters() const
   return validPL;
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+void Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::
+#else
 template <typename Scalar>
 void Piro::RythmosSolver<Scalar>::
-addStepperFactory(const std::string & stepperName,const Teuchos::RCP<RythmosStepperFactory<Scalar> > & factory)
+#endif
+addStepperFactory(const std::string & stepperName,const Teuchos::RCP<Piro::RythmosStepperFactory<Scalar> > & factory)
 {
   stepperFactories[stepperName] = factory;
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+void Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>::
+#else
 template <typename Scalar>
 void Piro::RythmosSolver<Scalar>::
+#endif
 addStepControlFactory(const std::string & stepControlName,
-                      const Teuchos::RCP<RythmosStepControlFactory<Scalar>> & step_control_strategy)
+                      const Teuchos::RCP<Piro::RythmosStepControlFactory<Scalar>> & step_control_strategy)
 {
   stepControlFactories[stepControlName] = step_control_strategy;
 }
 
+#ifdef ALBANY_BUILD
+template <typename Scalar, typename LocalOrdinal, typename GlobalOrdinal, typename Node>
+Teuchos::RCP<Piro::RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node> >
+#else
 template <typename Scalar>
 Teuchos::RCP<Piro::RythmosSolver<Scalar> >
+#endif
 Piro::rythmosSolver(
     const Teuchos::RCP<Teuchos::ParameterList> &appParams,
     const Teuchos::RCP<Thyra::ModelEvaluator<Scalar> > &in_model,
@@ -1004,6 +1110,11 @@ Piro::rythmosSolver(
         new ObserverToRythmosIntegrationObserverAdapter<Scalar>(piroObserver));
   }
 
+#ifdef ALBANY_BUILD
+  return Teuchos::rcp(new RythmosSolver<Scalar, LocalOrdinal, GlobalOrdinal, Node>(appParams, in_model, observer));
+#else
   return Teuchos::rcp(new RythmosSolver<Scalar>(appParams, in_model, observer));
+#endif
+
 }
 
