@@ -351,52 +351,6 @@ public:
     r[nx_-1] += nl_*(u1_*u[nx_-1]/6.0 + u1_*u1_/6.0) - nu_*u1_/dx_;
   }
 
-  // Solve PDE
-  void solve(std::vector<Real> &u, const std::vector<Real> &z) const {
-    u.assign(nx_,1.0);
-    // Compute residual and residual norm
-    std::vector<Real> r(u.size(),0.0);
-    compute_residual(r,u,z);
-    Real rnorm = compute_L2_norm(r);
-    // Define tolerances
-    Real rtol  = 1.e2*ROL::ROL_EPSILON;
-    Real maxit = 500;
-    // Initialize Jacobian storage
-    std::vector<Real> d(nx_,0.0);
-    std::vector<Real> dl(nx_-1,0.0);
-    std::vector<Real> du(nx_-1,0.0);
-    // Iterate Newton's method
-    Real alpha = 1.0, tmp = 0.0;
-    std::vector<Real> s(nx_,0.0);
-    std::vector<Real> utmp(nx_,0.0);
-    for (int i=0; i<maxit; i++) {
-      //std::cout << i << "  " << rnorm << "\n";
-      // Get Jacobian
-      compute_pde_jacobian(dl,d,du,u);
-      // Solve Newton system
-      linear_solve(s,dl,d,du,r);
-      // Perform line search
-      tmp = rnorm;
-      alpha = 1.0;
-      utmp.assign(u.begin(),u.end());
-      update(utmp,s,-alpha);
-      compute_residual(r,utmp,z);
-      rnorm = compute_L2_norm(r); 
-      while ( rnorm > (1.0-1.e-4*alpha)*tmp && alpha > std::sqrt(ROL::ROL_EPSILON) ) {
-        alpha /= 2.0;
-        utmp.assign(u.begin(),u.end());
-        update(utmp,s,-alpha);
-        compute_residual(r,utmp,z);
-        rnorm = compute_L2_norm(r); 
-      }
-      // Update iterate
-      u.assign(utmp.begin(),utmp.end());
-      if ( rnorm < rtol ) {
-        break;
-      }
-    }
-  }
-
   /***************************************************************************/
   /*********************** PDE JACOBIAN FUNCTIONS ****************************/
   /***************************************************************************/
@@ -949,20 +903,6 @@ public:
     fem_->compute_residual(*cp,*up,*zp);
   }
 
-  void solve(ROL::Vector<Real> &u, const ROL::Vector<Real> &z, Real &tol) {
-    Teuchos::RCP<std::vector<Real> > up =
-      Teuchos::rcp_const_cast<std::vector<Real> >((Teuchos::dyn_cast<PrimalStateVector>(u)).getVector());
-    up->assign(up->size(),z.norm()/up->size());
-    Teuchos::RCP<const std::vector<Real> > zp =
-      (Teuchos::dyn_cast<PrimalControlVector>(const_cast<ROL::Vector<Real> &>(z))).getVector();
-
-    const std::vector<Real> param
-      = ROL::ParametrizedEqualityConstraint_SimOpt<Real>::getParameter();
-    fem_->set_problem_data(param[0],param[1],param[2],param[3]);
-
-    fem_->solve(*up,*zp);
-  }
-
   void applyJacobian_1(ROL::Vector<Real> &jv, const ROL::Vector<Real> &v, const ROL::Vector<Real> &u, 
                        const ROL::Vector<Real> &z, Real &tol) {
     Teuchos::RCP<std::vector<Real> > jvp =
