@@ -49,7 +49,7 @@
 
 namespace {
   const unsigned int HASHSIZE = 5939;
-  const char* version_string = "4.23 (2015/07/20)";
+  const char* version_string = "4.25 (2015/11/24)";
   
   unsigned hash_symbol (const char *symbol)
   {
@@ -58,6 +58,7 @@ namespace {
       hashval = *symbol + 65599 * hashval;
     return (hashval % HASHSIZE);
   }
+  void output_copyright();
 }
 
 namespace SEAMS {
@@ -72,10 +73,10 @@ namespace SEAMS {
       isCollectingLoop(false), inIfdefGetvar(false)
   {
     ap_file_list.push(file_rec());
-    init_table("#");
+    init_table("$");
     aprepro = this;
 
-    // See the random number generator...
+    // Seed the random number generator...
     time_t time_val = std::time ((time_t*)NULL);
     srand((unsigned)time_val);
   }
@@ -108,20 +109,18 @@ namespace SEAMS {
   
   bool Aprepro::parse_stream(std::istream& in, const std::string& in_name)
   {
+    std::istream *in_cpy = &in;
     ap_file_list.top().name = in_name;
 
+    Scanner *scanner = new Scanner(*this, in_cpy, &parsingResults);
+    this->lexer = scanner;
+
     if (!ap_options.include_file.empty()) {
-      file_rec include_file(ap_options.include_file.c_str(), 0, false, 0);
-      ap_file_list.push(include_file);
-      // File included on command line will be processed as immutable and no-echo
-      // Will revert to global settings at end of file.
       stateImmutable = true;
       echo = false;
+      scanner->add_include_file(ap_options.include_file, true);
     }
 
-    Scanner *scanner = new Scanner(*this, &in, &parsingResults);
-    this->lexer = scanner;
-
     Parser parser(*this);
     parser.set_debug_level(ap_options.trace_parsing);
     return (parser.parse() == 0);
@@ -156,18 +155,15 @@ namespace SEAMS {
     if(ap_file_list.size() == 1)
       ap_file_list.top().name = "interactive_input";
 
-    if (!ap_options.include_file.empty()) {
-      file_rec include_file(ap_options.include_file.c_str(), 0, false, 0);
-      ap_file_list.push(include_file);
-      // File included on command line will be processed as immutable and no-echo
-      // Will revert to global settings at end of file.
-      stateImmutable = true;
-      echo = false;
-    }
-
     if(!stringScanner)
       stringScanner = new Scanner(*this, &stringInput, &parsingResults);
 
+    if (!ap_options.include_file.empty()) {
+      stateImmutable = true;
+      echo = false;
+      stringScanner->add_include_file(ap_options.include_file, true);
+    }
+
     this->lexer = stringScanner;
 
     stringInput.str(input);
@@ -214,7 +210,7 @@ namespace SEAMS {
 
     if(line_info) {
       ss << " (" << ap_file_list.top().name <<
-            ", line " << ap_file_list.top().lineno + 1 << ")";
+	", line " << ap_file_list.top().lineno + 1 << ")";
     }
     ss << "\n";
 
@@ -235,7 +231,7 @@ namespace SEAMS {
 
     if(line_info) {
       ss << " (" << ap_file_list.top().name <<
-            ", line " << ap_file_list.top().lineno + 1 << ")";
+	", line " << ap_file_list.top().lineno + 1 << ")";
     }
     ss << "\n";
 
@@ -346,7 +342,7 @@ namespace SEAMS {
       symrec *ptr = getsym(sym_name.c_str());
       if (ptr != NULL) {
 	if (ptr->type != parser_type) {
-    error("Overloaded function " + sym_name + "does not return same type", false);
+	  error("Overloaded function " + sym_name + "does not return same type", false);
 	  exit(EXIT_FAILURE);
 	}
 	// Function with this name already exists; return that
@@ -367,26 +363,32 @@ namespace SEAMS {
     return ptr;
   }
 
-  bool Aprepro::set_option(const std::string &option)
+  int Aprepro::set_option(const std::string &option, const std::string &optional_value)
   {
     // Option should be of the form "--option" or "-O"
     // I.e., double dash for long option, single dash for short.
     // Option can be followed by "=value" if the option requires
-    // a value.
+    // a value.  The value will either be part of 'option' if it contains
+    // an '=', or it will be in 'optional_value'.  if 'optional_value' used,
+    // return 1; else return 0;
 
+    
     // Some options (--include) 
+    int ret_value = 0;
     
     if (option == "--debug" || option == "-d") {
       ap_options.debugging = true;
     }
     else if (option == "--version" || option == "-v") {
-      std::cerr << "Aprepro version " << version() << "\n";
+      std::cerr << "Algebraic Preprocessor (Aprepro) version " << version() << "\n";
+      exit(EXIT_SUCCESS);
     }
     else if (option == "--nowarning" || option == "-W") {
       ap_options.warning_msg = false;
     }
     else if (option == "--copyright" || option == "-C") {
-      copyright();
+      output_copyright();
+      exit(EXIT_SUCCESS);
     }
     else if (option == "--message" || option == "-M") {
       ap_options.info_msg = true;
@@ -407,20 +409,55 @@ namespace SEAMS {
     else if (option == "--exit_on" || option == "-e") {
       ap_options.end_on_exit = true;
     }
-    else if (option.find("--include=") != std::string::npos || (option[1] == 'I' && option[2] == '=')) {
+    else if (option.find("--include") != std::string::npos || (option[1] == 'I')) {
+      std::string value("");
+      
       size_t index = option.find_first_of('=');
-      std::string file_or_path = option.substr(index+1);
-      if (is_directory(file_or_path)) {
-	ap_options.include_path = file_or_path;
+      if (index != std::string::npos) {
+	value = option.substr(index+1);
+      }
+      else {
+	value = optional_value;
+	ret_value = 1;
+      }
+
+      if (is_directory(value)) {
+	ap_options.include_path = value;
       } else {
-	ap_options.include_file = file_or_path;
+	ap_options.include_file = value;
       }
     }
     else if (option == "--keep_history" || option == "-k") {
       ap_options.keep_history = true;
     }
+
+    else if (option.find("--comment") != std::string::npos || (option[1] == 'c')) {
+      std::string comment = "";
+      // In short version, do not require equal sign (-c# -c// )
+      if (option[1] == 'c' && option.length() > 2 && option[2] != '=') {
+	comment = option.substr(2);
+      }
+      else {
+	size_t index = option.find_first_of('=');
+	if (index != std::string::npos) {
+	  comment = option.substr(index+1);
+	}
+	else {
+	  comment = optional_value;
+	  ret_value = 1;
+	}
+      }
+      symrec *ptr = getsym("_C_");
+      if (ptr != NULL) {
+	char *tmp = NULL;
+	new_string(comment.c_str(), &tmp);
+	ptr->value.svar = tmp;
+      }
+    }
+
     else if (option == "--help" || option == "-h") {
-      std::cerr << "\nAPREPRO PREPROCESSOR OPTIONS:\n"
+      std::cerr << "\nAprepro version " << version() << "\n"
+		<< "\nUsage: aprepro [options] [-I path] [-c char] [var=val] [filein] [fileout]\n"
 		<< "          --debug or -d: Dump all variables, debug loops/if/endif\n"
 		<< "        --version or -v: Print version number to stderr          \n"
 		<< "      --immutable or -X: All variables are immutable--cannot be modified\n"
@@ -433,24 +470,29 @@ namespace SEAMS {
 		<< "           --help or -h: Print this list                         \n"
 		<< "        --message or -M: Print INFO messages                     \n"
 		<< "      --nowarning or -W: Do not print WARN messages              \n"
-    << "      --copyright or -C: Print copyright message                 \n"
-    << "   --keep_history or -k: Keep a history of aprepro substitutions.\n\n"
+		<< "  --comment=char or -c=char: Change comment character to 'char'      \n"
+		<< "      --copyright or -C: Print copyright message                 \n"
+		<< "   --keep_history or -k: Keep a history of aprepro substitutions.\n"
+		<< "          --quiet or -q: (ignored)                               \n"
+		<< "                var=val: Assign value 'val' to variable 'var'    \n"
+		<< "                         Use var=\\\"sval\\\" for a string variable\n\n"
 	        << "\tUnits Systems: si, cgs, cgs-ev, shock, swap, ft-lbf-s, ft-lbm-s, in-lbf-s\n"
 		<< "\tEnter {DUMP_FUNC()} for list of functions recognized by aprepro\n"
 		<< "\tEnter {DUMP_PREVAR()} for list of predefined variables in aprepro\n\n"
 		<< "\t->->-> Send email to gdsjaar@sandia.gov for aprepro support.\n\n";
+      exit(EXIT_SUCCESS);
     }
-    return true;
+    return ret_value;
   }
   
   void Aprepro::add_variable(const std::string &sym_name, const std::string &sym_value, bool immutable)
   {
     if (check_valid_var(sym_name.c_str())) {
-    SYMBOL_TYPE type = immutable ? IMMUTABLE_STRING_VARIABLE : STRING_VARIABLE;
-    symrec *var = putsym(sym_name, type, false);
-    char *tmp = NULL;
-    new_string(sym_value.c_str(), &tmp);
-    var->value.svar = tmp;
+      SYMBOL_TYPE type = immutable ? IMMUTABLE_STRING_VARIABLE : STRING_VARIABLE;
+      symrec *var = putsym(sym_name, type, false);
+      char *tmp = NULL;
+      new_string(sym_value.c_str(), &tmp);
+      var->value.svar = tmp;
     }
     else {
       warning("Invalid variable name syntax '" + sym_name + "'. Variable not defined.\n", false);
@@ -474,29 +516,29 @@ namespace SEAMS {
     std::vector<std::string> names;
 
     for(unsigned int hashval = 0; hashval < HASHSIZE; hashval++)
-    {
-      for(symrec *ptr = sym_table[hashval]; ptr != NULL; ptr = ptr->next)
       {
-        if(ptr->isInternal != doInternal)
-          continue;
+	for(symrec *ptr = sym_table[hashval]; ptr != NULL; ptr = ptr->next)
+	  {
+	    if(ptr->isInternal != doInternal)
+	      continue;
 
-        switch(ptr->type)
-        {
-          case Parser::token::VAR:
-          case Parser::token::IMMVAR:
-          case Parser::token::SVAR:
-          case Parser::token::IMMSVAR:
-          case Parser::token::AVAR:
-            // Add to our vector
-            names.push_back(ptr->name);
-            break;
+	    switch(ptr->type)
+	      {
+	      case Parser::token::VAR:
+	      case Parser::token::IMMVAR:
+	      case Parser::token::SVAR:
+	      case Parser::token::IMMSVAR:
+	      case Parser::token::AVAR:
+		// Add to our vector
+		names.push_back(ptr->name);
+		break;
 
-          default:
-            // Do nothing
-            break;
-        }
+	      default:
+		// Do nothing
+		break;
+	      }
+	  }
       }
-    }
 
     return names;
   }
@@ -505,52 +547,52 @@ namespace SEAMS {
   {
     symrec *ptr = getsym(sym_name.c_str());
     bool is_valid_variable =
-        (ptr != NULL) && (!ptr->isInternal) &&
-        ((ptr->type == Parser::token::VAR) ||
-         (ptr->type == Parser::token::SVAR) ||
-         (ptr->type == Parser::token::AVAR) ||
-         (ptr->type == Parser::token::IMMVAR) ||
-         (ptr->type == Parser::token::IMMSVAR) ||
-         (ptr->type == Parser::token::UNDVAR));
+      (ptr != NULL) && (!ptr->isInternal) &&
+      ((ptr->type == Parser::token::VAR) ||
+       (ptr->type == Parser::token::SVAR) ||
+       (ptr->type == Parser::token::AVAR) ||
+       (ptr->type == Parser::token::IMMVAR) ||
+       (ptr->type == Parser::token::IMMSVAR) ||
+       (ptr->type == Parser::token::UNDVAR));
 
     if(is_valid_variable)
-    {
-      int hashval = hash_symbol(sym_name.c_str());
-      symrec *hash_ptr = sym_table[hashval];
-
-      // Handle the case if the variable we want to delete is first in the
-      // linked list.
-      if(ptr == hash_ptr)
       {
-        // NOTE: If ptr is the only thing in the linked list, ptr->next will be
-        // NULL, which is what we want in sym_table when we delete ptr.
-        sym_table[hashval] = ptr->next;
-        delete ptr;
-      }
+	int hashval = hash_symbol(sym_name.c_str());
+	symrec *hash_ptr = sym_table[hashval];
 
-      // Handle the case where the variable we want to delete is somewhere
-      // in the middle or at the end of the linked list.
-      else
-      {
-        // Find the preceeding ptr (singly linked list).
-        // NOTE: We don't have a check for NULL here because the fact that
-        // ptr != hash_ptr tells us that we must have more than one item in our
-        // linked list, in which case hash_ptr->next will not be NULL until we
-        // reach the end of the list. hash_ptr->next should be equal to ptr
-        // before that happens.
-        while(hash_ptr->next != ptr)
-          hash_ptr = hash_ptr->next;
+	// Handle the case if the variable we want to delete is first in the
+	// linked list.
+	if(ptr == hash_ptr)
+	  {
+	    // NOTE: If ptr is the only thing in the linked list, ptr->next will be
+	    // NULL, which is what we want in sym_table when we delete ptr.
+	    sym_table[hashval] = ptr->next;
+	    delete ptr;
+	  }
 
-        // NOTE: If ptr is at the end of the list ptr->next will be NULL, in
-        // which case this will change hash_ptr to be the end of the list.
-        hash_ptr->next = ptr->next;
-        delete ptr;
+	// Handle the case where the variable we want to delete is somewhere
+	// in the middle or at the end of the linked list.
+	else
+	  {
+	    // Find the preceeding ptr (singly linked list).
+	    // NOTE: We don't have a check for NULL here because the fact that
+	    // ptr != hash_ptr tells us that we must have more than one item in our
+	    // linked list, in which case hash_ptr->next will not be NULL until we
+	    // reach the end of the list. hash_ptr->next should be equal to ptr
+	    // before that happens.
+	    while(hash_ptr->next != ptr)
+	      hash_ptr = hash_ptr->next;
+
+	    // NOTE: If ptr is at the end of the list ptr->next will be NULL, in
+	    // which case this will change hash_ptr to be the end of the list.
+	    hash_ptr->next = ptr->next;
+	    delete ptr;
+	  }
       }
-    }
     else
-    {
-      warning("Variable '" + sym_name + "' not defined.\n", false);
-    }
+      {
+	warning("Variable '" + sym_name + "' not defined.\n", false);
+      }
   }
 
   symrec *Aprepro::getsym (const char *sym_name) const
@@ -574,22 +616,22 @@ namespace SEAMS {
 	for (symrec *ptr = sym_table[hashval]; ptr != NULL; ptr = ptr->next) {
 	  if ((doInternal && ptr->isInternal) || (!doInternal && !ptr->isInternal)) {
 	    if (ptr->type == Parser::token::VAR)
-        (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
-                         "\t= " << std::setprecision(10) <<  ptr->value.var << "}" << std::endl;
+	      (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
+		"\t= " << std::setprecision(10) <<  ptr->value.var << "}" << std::endl;
 	    else if (ptr->type == Parser::token::IMMVAR)
-        (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
-                         "\t= " << std::setprecision(10) << ptr->value.var << "}\t(immutable)" << std::endl;
-      else if (ptr->type == Parser::token::SVAR)
-        (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
-                         "\t= \"" << ptr->value.svar << "\"}" << std::endl;
+	      (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
+		"\t= " << std::setprecision(10) << ptr->value.var << "}\t(immutable)" << std::endl;
+	    else if (ptr->type == Parser::token::SVAR)
+	      (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
+		"\t= \"" << ptr->value.svar << "\"}" << std::endl;
 	    else if (ptr->type == Parser::token::IMMSVAR)
-        (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
-                         "\t= \"" << ptr->value.svar << "\"}\t(immutable)" << std::endl;
+	      (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
+		"\t= \"" << ptr->value.svar << "\"}\t(immutable)" << std::endl;
 	    else if (ptr->type == Parser::token::AVAR) {
 	      array *arr = ptr->value.avar;
-        (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
-                         "\t (array) rows = " << arr->rows << ", cols = " << arr->cols <<
-                         "} " << std::endl;
+	      (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name <<
+		"\t (array) rows = " << arr->rows << ", cols = " << arr->cols <<
+		"} " << std::endl;
 	    }
 	  }
 	}
@@ -600,8 +642,8 @@ namespace SEAMS {
       for (unsigned hashval = 0; hashval < HASHSIZE; hashval++) {
 	for (symrec *ptr = sym_table[hashval]; ptr != NULL; ptr = ptr->next) {
 	  if (ptr->type == Parser::token::FNCT) {
-      (*infoStream) << std::left << std::setw(2*width) << ptr->syntax <<
-                       ":  " << ptr->info << std::endl;
+	    (*infoStream) << std::left << std::setw(2*width) << ptr->syntax <<
+	      ":  " << ptr->info << std::endl;
 	  }
 	}
       }
@@ -610,8 +652,8 @@ namespace SEAMS {
       for (unsigned hashval = 0; hashval < HASHSIZE; hashval++) {
 	for (symrec *ptr = sym_table[hashval]; ptr != NULL; ptr = ptr->next) {
 	  if (ptr->type == Parser::token::SFNCT) {
-      (*infoStream) << std::left << std::setw(2*width) << ptr->syntax <<
-                       ":  " << ptr->info << std::endl;
+	    (*infoStream) << std::left << std::setw(2*width) << ptr->syntax <<
+	      ":  " << ptr->info << std::endl;
 	  }
 	}
       }
@@ -620,8 +662,8 @@ namespace SEAMS {
       for (unsigned hashval = 0; hashval < HASHSIZE; hashval++) {
 	for (symrec *ptr = sym_table[hashval]; ptr != NULL; ptr = ptr->next) {
 	  if (ptr->type == Parser::token::AFNCT) {
-      (*infoStream) << std::left << std::setw(2*width) << ptr->syntax <<
-                       ":  " << ptr->info << std::endl;
+	    (*infoStream) << std::left << std::setw(2*width) << ptr->syntax <<
+	      ":  " << ptr->info << std::endl;
 	  }
 	}
       }
@@ -687,29 +729,20 @@ namespace SEAMS {
       (*output) << longer << " chain(s) of length " << MAXLEN << " or longer\n";
   }
 
-  void Aprepro::copyright(std::ostream *out) const
-  {
-    std::ostream *output = out;
-    if (output == NULL)
-      output = &std::cout;
-    
-    (*output) << "COPYRIGHT NOTICE\n";
-  }
-
   void Aprepro::add_history(const std::string& original, const std::string& substitution)
   {
     if(!ap_options.keep_history)
       return;
 
     if(!original.empty())
-    {
-      history_data hist;
-      hist.original = original;
-      hist.substitution = substitution;
-      hist.index = outputStream.top()->tellp();
+      {
+	history_data hist;
+	hist.original = original;
+	hist.substitution = substitution;
+	hist.index = outputStream.top()->tellp();
 
-      history.push_back(hist);
-    }
+	history.push_back(hist);
+      }
   }
 
   const std::vector<history_data>& Aprepro::get_history()
@@ -723,3 +756,41 @@ namespace SEAMS {
       history.clear();
   }
 }
+
+namespace {
+  void output_copyright()
+  {
+    std::cerr
+      << "\n\tCopyright (c) 2014 Sandia Corporation.\n"
+      << "\tUnder the terms of Contract DE-AC04-94AL85000 with Sandia Corporation,\n"
+      << "\tthe U.S. Government retains certain rights in this software.\n"
+      << "\n"
+      << "\tRedistribution and use in source and binary forms, with or without\n"
+      << "\tmodification, are permitted provided that the following conditions\n"
+      << "\tare met:\n"
+      << "\n"
+      << "\t   * Redistributions of source code must retain the above copyright\n"
+      << "\t     notice, this list of conditions and the following disclaimer.\n"
+      << "\t   * Redistributions in binary form must reproduce the above\n"
+      << "\t     copyright notice, this list of conditions and the following\n"
+      << "\t     disclaimer in the documentation and/or other materials provided\n"
+      << "\t     with the distribution.\n"
+      << "\t   * Neither the name of Sandia Corporation nor the names of its\n"
+      << "\t     contributors may be used to endorse or promote products derived\n"
+      << "\t     from this software without specific prior written permission.\n"
+      << "\n"
+      << "\tTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS\n"
+      << "\t'AS IS' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT\n"
+      << "\tLIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR\n"
+      << "\tA PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT\n"
+      << "\tOWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,\n"
+      << "\tSPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT\n"
+      << "\tLIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,\n"
+      << "\tDATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY\n"
+      << "\tTHEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT\n"
+      << "\t(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE\n"
+      << "\tOF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.\n\n";
+
+  } 
+}
+
