@@ -73,6 +73,23 @@ static void set_count(int exoid, void_int *cnt, size_t ndx, size_t val)
   }
 }
 
+static int check_valid_side(size_t side_num, size_t max_sides, char *topology, int exoid)
+{
+  char errmsg[MAX_ERR_LENGTH];
+  int err_stat = EX_NOERR;
+
+  exerrval = 0;
+  if (side_num+1 < 1 || side_num+1 > max_sides) {
+    exerrval = EX_BADPARAM;
+    sprintf(errmsg,
+	    "Error: Invalid %s edge number %"ST_ZU" in file id %d",
+	    topology, side_num+1, exoid);
+    ex_err("ex_get_side_set_node_list",errmsg,exerrval);
+    err_stat = EX_FATAL;
+  }
+  return err_stat;
+}
+  
 static void get_nodes(int exoid, void_int *to, size_t ito, void_int *from, size_t ifrom)
 {
   if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
@@ -87,7 +104,6 @@ int ex_get_side_set_node_list(int exoid,
 			      void_int *side_set_node_cnt_list,
 			      void_int *side_set_node_list)
 {
-  size_t m;
   size_t i, j; 
   int64_t elem, side;
   int64_t num_side_sets, num_elem_blks, num_df, ndim;
@@ -138,18 +154,18 @@ int ex_get_side_set_node_list(int exoid,
   };
 
   /* shell */
-  static int shell_table[6][8] = {
-    /*        1                  2                                       side   */
-    {1,2,3,4,5,6,7,8}, {1,4,3,2,8,7,6,5} ,                          /* nodes  */
-    /*        3                  4                                       side   */
-    {1,2,5,0,0,0,0,0}, {2,3,6,0,0,0,0,0} ,                          /* nodes  */
-    /*        5                  6                                       side   */
-    {3,4,7,0,0,0,0,0}, {4,1,8,0,0,0,0,0}                            /* nodes  */
+  static int shell_table[6][9] = {
+    /*        1                  2                                 side   */
+    {1,2,3,4,5,6,7,8,9}, {1,4,3,2,8,7,6,5,9} ,                     /* nodes  */
+    /*        3                  4                                 side   */
+    {1,2,5,0,0,0,0,0,0}, {2,3,6,0,0,0,0,0,0} ,                     /* nodes  */
+    /*        5                  6                                 side   */
+    {3,4,7,0,0,0,0,0,0}, {4,1,8,0,0,0,0,0,0}                       /* nodes  */
   };
 
   /* tetra */
   static int tetra_table[4][6] = {
-    /*      1              2               3               4            side   */
+    /*      1              2               3               4       side   */
     {1,2,4,5,9,8}, {2,3,4,6,10,9}, {1,4,3,8,10,7}, {1,3,2,7,6,5}   /* nodes  */
   };
 
@@ -560,15 +576,8 @@ int ex_get_side_set_node_list(int exoid,
       case EX_EL_TRIANGLE:
 	{
 	  if (ndim == 2) {   /* 2d TRIs */
-	    if (side_num+1 < 1 || side_num+1 > 3) {
-	      exerrval = EX_BADPARAM;
-	      sprintf(errmsg,
-		      "Error: Invalid triangle edge number %"ST_ZU" in file id %d",
-		      side_num+1, exoid);
-	      ex_err("ex_get_side_set_node_list",errmsg,exerrval);
-	      err_stat = EX_FATAL;
+	    if (check_valid_side(side_num, 3, "triangle", exoid) != EX_NOERR)
 	      goto cleanup;
-	    }
 
 	    get_nodes(exoid, side_set_node_list, node_pos,   connect, connect_offset+tri_table[side_num][0]-1);
 	    get_nodes(exoid, side_set_node_list, node_pos+1, connect, connect_offset+tri_table[side_num][1]-1);
@@ -580,15 +589,8 @@ int ex_get_side_set_node_list(int exoid,
 	      }
 	  }
 	  else if (ndim == 3) {  /* 3d TRIs */
-	    if (side_num+1 < 1 || side_num+1 > 5) {
-	      exerrval = EX_BADPARAM;
-	      sprintf(errmsg,
-		      "Error: Invalid triangle edge number %"ST_ZU" in file id %d",
-		      side_num+1, exoid);
-	      ex_err("ex_get_side_set_node_list",errmsg,exerrval);
-	      err_stat = EX_FATAL;
+	    if (check_valid_side(side_num, 5, "triangle", exoid) != EX_NOERR)
 	      goto cleanup;
-	    }
 
 	    get_nodes(exoid, side_set_node_list, node_pos,   connect, connect_offset+tri3_table[side_num][0]-1);
 	    get_nodes(exoid, side_set_node_list, node_pos+1, connect, connect_offset+tri3_table[side_num][1]-1);
@@ -622,16 +624,8 @@ int ex_get_side_set_node_list(int exoid,
 	}
       case EX_EL_QUAD:
 	{
-	  if (side_num+1 < 1 || side_num+1 > 4) /* side number range check */
-	    {
-	      exerrval = EX_BADPARAM;
-	      sprintf(errmsg,
-		      "Error: Invalid quad edge number %"ST_ZU" in file id %d",
-		      side_num+1, exoid);
-	      ex_err("ex_get_side_set_node_list",errmsg,exerrval);
-	      err_stat = EX_FATAL;
-	      goto cleanup;
-	    }
+	  if (check_valid_side(side_num, 4, "quad", exoid) != EX_NOERR)
+	    goto cleanup;
         
 	  get_nodes(exoid, side_set_node_list, node_pos+0, connect, connect_offset+quad_table[side_num][0]-1);
 	  get_nodes(exoid, side_set_node_list, node_pos+1, connect, connect_offset+quad_table[side_num][1]-1);
@@ -645,59 +639,52 @@ int ex_get_side_set_node_list(int exoid,
 	}
       case EX_EL_SHELL:
 	{
-	  if (side_num+1 < 1 || side_num+1 > 6) /* side number range check */
-	    {
-	      exerrval = EX_BADPARAM;
-	      sprintf(errmsg,
-		      "Error: Invalid shell face number %"ST_ZU" in file id %d",
-		      side_num+1, exoid);
-	      ex_err("ex_get_side_set_node_list",errmsg,exerrval);
-	      err_stat = EX_FATAL;
-	      goto cleanup;
-	    }
+	  if (check_valid_side(side_num, 6, "shell", exoid) != EX_NOERR)
+	    goto cleanup;
 
 	  get_nodes(exoid, side_set_node_list, node_pos+0, connect, connect_offset+shell_table[side_num][0]-1);
 	  get_nodes(exoid, side_set_node_list, node_pos+1, connect, connect_offset+shell_table[side_num][1]-1);
 	  set_count(exoid, side_set_node_cnt_list, elem_ndx, 2);   /* 2 node object */
-	  if (num_nodes_per_elem > 2) /*** KLUDGE for 2D shells ***/
-	    {
-	      if (side_num+1 <= 2)  /* 4-node face */
-		{
-		  set_count(exoid, side_set_node_cnt_list, elem_ndx, 4);   /* 4 node object */
-		  get_nodes(exoid, side_set_node_list, node_pos+2, connect, connect_offset+shell_table[side_num][2]-1);
-		  get_nodes(exoid, side_set_node_list, node_pos+3, connect, connect_offset+shell_table[side_num][3]-1);
-		}
+	  if (num_nodes_per_elem > 2) { /*** KLUGE for 2D shells ***/
+	    if (side_num+1 <= 2) { /* 4-node face */
+	      set_count(exoid, side_set_node_cnt_list, elem_ndx, 4);   /* 4 node object */
+	      get_nodes(exoid, side_set_node_list, node_pos+2, connect, connect_offset+shell_table[side_num][2]-1);
+	      get_nodes(exoid, side_set_node_list, node_pos+3, connect, connect_offset+shell_table[side_num][3]-1);
 	    }
-	  if (num_nodes_per_elem == 8)
-	    {
-	      if (side_num+1 <= 2)  /* 8-node face */
-		{
-		  set_count(exoid, side_set_node_cnt_list, elem_ndx, 8); /* 8 node object */
-		  get_nodes(exoid, side_set_node_list, node_pos+4, connect, connect_offset+shell_table[side_num][4]-1);
-		  get_nodes(exoid, side_set_node_list, node_pos+5, connect, connect_offset+shell_table[side_num][5]-1);
-		  get_nodes(exoid, side_set_node_list, node_pos+6, connect, connect_offset+shell_table[side_num][6]-1);
-		  get_nodes(exoid, side_set_node_list, node_pos+7, connect, connect_offset+shell_table[side_num][7]-1);
-		}
-	      else 
-		{
-		  set_count(exoid, side_set_node_cnt_list, elem_ndx, 3); /* 3 node edge */
-		  get_nodes(exoid, side_set_node_list, node_pos+2, connect, connect_offset+shell_table[side_num][2]-1);
-		}
+	  }
+	  if (num_nodes_per_elem == 8) {
+	    if (side_num+1 <= 2) {  /* 8-node face */
+	      set_count(exoid, side_set_node_cnt_list, elem_ndx, 8); /* 8 node object */
+	      get_nodes(exoid, side_set_node_list, node_pos+4, connect, connect_offset+shell_table[side_num][4]-1);
+	      get_nodes(exoid, side_set_node_list, node_pos+5, connect, connect_offset+shell_table[side_num][5]-1);
+	      get_nodes(exoid, side_set_node_list, node_pos+6, connect, connect_offset+shell_table[side_num][6]-1);
+	      get_nodes(exoid, side_set_node_list, node_pos+7, connect, connect_offset+shell_table[side_num][7]-1);
 	    }
+	    else {
+	      set_count(exoid, side_set_node_cnt_list, elem_ndx, 3); /* 3 node edge */
+	      get_nodes(exoid, side_set_node_list, node_pos+2, connect, connect_offset+shell_table[side_num][2]-1);
+	    }
+	  }
+	  if (num_nodes_per_elem == 9) {
+	    if (side_num+1 <= 2) {  /* 9-node face */
+	      set_count(exoid, side_set_node_cnt_list, elem_ndx, 9); /* 9 node object */
+	      get_nodes(exoid, side_set_node_list, node_pos+4, connect, connect_offset+shell_table[side_num][4]-1);
+	      get_nodes(exoid, side_set_node_list, node_pos+5, connect, connect_offset+shell_table[side_num][5]-1);
+	      get_nodes(exoid, side_set_node_list, node_pos+6, connect, connect_offset+shell_table[side_num][6]-1);
+	      get_nodes(exoid, side_set_node_list, node_pos+7, connect, connect_offset+shell_table[side_num][7]-1);
+	      get_nodes(exoid, side_set_node_list, node_pos+8, connect, connect_offset+shell_table[side_num][8]-1);
+	    }
+	    else {
+	      set_count(exoid, side_set_node_cnt_list, elem_ndx, 3); /* 3 node edge */
+	      get_nodes(exoid, side_set_node_list, node_pos+2, connect, connect_offset+shell_table[side_num][2]-1);
+	    }
+	  }
 	  break;
 	}
       case EX_EL_TETRA:
 	{
-	  if (side_num+1 < 1 || side_num+1 > 4) /* side number range check */
-	    {
-	      exerrval = EX_BADPARAM;
-	      sprintf(errmsg,
-		      "Error: Invalid tetra face number %"ST_ZU" in file id %d",
-		      side_num+1, exoid);
-	      ex_err("ex_get_side_set_node_list",errmsg,exerrval);
-	      err_stat = EX_FATAL;
-	      goto cleanup;
-	    }
+	  if (check_valid_side(side_num, 4, "tetra", exoid) != EX_NOERR)
+	    goto cleanup;
 
 	  get_nodes(exoid, side_set_node_list, node_pos+0, connect, connect_offset+tetra_table[side_num][0]-1);
 	  get_nodes(exoid, side_set_node_list, node_pos+1, connect, connect_offset+tetra_table[side_num][1]-1);
@@ -719,16 +706,8 @@ int ex_get_side_set_node_list(int exoid,
 	}
       case EX_EL_WEDGE:
 	{
-	  if (side_num+1 < 1 || side_num+1 > 5) /* side number range check */
-	    {
-	      exerrval = EX_BADPARAM;
-	      sprintf(errmsg,
-		      "Error: Invalid wedge face number %"ST_ZU" in file id %d",
-		      side_num+1, exoid);
-	      ex_err("ex_get_side_set_node_list",errmsg,exerrval);
-	      err_stat = EX_FATAL;
-	      goto cleanup;
-	    }
+	  if (check_valid_side(side_num, 5, "wedge", exoid) != EX_NOERR)
+	    goto cleanup;
 
 	  get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+wedge_table[side_num][0]-1);
 	  get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+wedge_table[side_num][1]-1);
@@ -744,34 +723,29 @@ int ex_get_side_set_node_list(int exoid,
 	    }
 
 
-	  if (num_nodes_per_elem > 6)
-	    {
+	  if (num_nodes_per_elem > 6) {
+	    /* Wedge 12 - 4-node quad faces (0,1,2) and 6-node tri faces (3,4) */
+	    /* Wedge 15 - 8-node quad faces (0,1,2) and 6-node tri faces (3,4) */
+
+	    if (num_nodes_per_elem > 12 || side_num == 3 || side_num == 4) {
 	      get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+wedge_table[side_num][4]-1);
 	      get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+wedge_table[side_num][5]-1);
 	      get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+wedge_table[side_num][6]-1);
 
 	      if (wedge_table[side_num][7] == 0) /* degenerate side? */
 		set_count(exoid, side_set_node_cnt_list, elem_ndx, 6);   /* 6 node side */
-	      else
-		{
-		  get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+wedge_table[side_num][7]-1);
-		  set_count(exoid, side_set_node_cnt_list, elem_ndx, 8);   /* 8 node side */
-		}
+	      else {
+		get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+wedge_table[side_num][7]-1);
+		set_count(exoid, side_set_node_cnt_list, elem_ndx, 8);   /* 8 node side */
+	      }
 	    }
+	  }
 	  break;
 	}
       case EX_EL_PYRAMID:
 	{
-	  if (side_num+1 < 1 || side_num+1 > 5) /* side number range check */
-	    {
-	      exerrval = EX_BADPARAM;
-	      sprintf(errmsg,
-		      "Error: Invalid pyramid face number %"ST_ZU" in file id %d",
-		      side_num+1, exoid);
-	      ex_err("ex_get_side_set_node_list",errmsg,exerrval);
-	      err_stat = EX_FATAL;
-	      goto cleanup;
-	    }
+	  if (check_valid_side(side_num, 5, "pyramid", exoid) != EX_NOERR)
+	    goto cleanup;
 
 	  get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+pyramid_table[side_num][0]-1);
 	  get_nodes(exoid, side_set_node_list, node_pos++, connect, connect_offset+pyramid_table[side_num][1]-1);
@@ -805,16 +779,8 @@ int ex_get_side_set_node_list(int exoid,
 	}
       case EX_EL_HEX:
 	{
-	  if (side_num+1 < 1 || side_num+1 > 6) /* side number range check */
-	    {
-	      exerrval = EX_BADPARAM;
-	      sprintf(errmsg,
-		      "Error: Invalid hex face number %"ST_ZU" in file id %d",
-		      side_num+1, exoid);
-	      ex_err("ex_get_side_set_node_list",errmsg,exerrval);
-	      err_stat = EX_FATAL;
-	      goto cleanup;
-	    }
+	  if (check_valid_side(side_num, 6, "hex", exoid) != EX_NOERR)
+	    goto cleanup;
 
 	  get_nodes(exoid, side_set_node_list, node_pos+0, connect, connect_offset+hex_table[side_num][0]-1);
 	  get_nodes(exoid, side_set_node_list, node_pos+1, connect, connect_offset+hex_table[side_num][1]-1);
