@@ -1002,7 +1002,7 @@ static int ex_inquire_internal (int      exoid,
 
   case EX_INQ_NUM_CHILD_GROUPS:
     /* return number of groups contained in this (exoid) group */
-#if !defined(NOT_NETCDF4)
+#if defined(ENABLE_NETCDF4)
     nc_inq_grps(exoid, &tmp_num, NULL);
     *ret_int = tmp_num;
 #endif
@@ -1010,7 +1010,7 @@ static int ex_inquire_internal (int      exoid,
     
   case EX_INQ_GROUP_PARENT:
     /* return id of parent of this (exoid) group; returns exoid if at root */
-#if !defined(NOT_NETCDF4)
+#if defined(ENABLE_NETCDF4)
     tmp_num = exoid;
     nc_inq_grp_parent(exoid, &tmp_num);
     *ret_int = tmp_num;
@@ -1024,7 +1024,7 @@ static int ex_inquire_internal (int      exoid,
     
   case EX_INQ_GROUP_NAME_LEN:
     {
-#if !defined(NOT_NETCDF4)
+#if defined(ENABLE_NETCDF4)
       size_t len_name = 0;
       /* return name length of group exoid */
       nc_inq_grpname_len(exoid, &len_name);
@@ -1042,14 +1042,14 @@ static int ex_inquire_internal (int      exoid,
       ex_err("ex_inquire",errmsg,exerrval);
       return (EX_FATAL);
     }
-#if !defined(NOT_NETCDF4)
+#if defined(ENABLE_NETCDF4)
     nc_inq_grpname(exoid, ret_char);
 #endif    
     break;
     
   case EX_INQ_FULL_GROUP_NAME_LEN:
     {
-#if !defined(NOT_NETCDF4)
+#if defined(ENABLE_NETCDF4)
       size_t len_name = 0;
       /* return length of full group name which is the "/" separated path from root
        * For example "/group1/subgroup1/subsubgroup1"
@@ -1072,7 +1072,7 @@ static int ex_inquire_internal (int      exoid,
       ex_err("ex_inquire",errmsg,exerrval);
       return (EX_FATAL);
     }
-#if !defined(NOT_NETCDF4)
+#if defined(ENABLE_NETCDF4)
     nc_inq_grpname_full(exoid, NULL, ret_char);
 #endif    
     break;
