@@ -89,8 +89,8 @@ int ex_put_cmap_params_cc(int  exoid,
   size_t ecnt_cmap, ncnt_cmap;
 
   long long nl_ecnt_cmap, nl_ncnt_cmap;
-  long long *n_var_idx = NULL;
-  long long *e_var_idx = NULL;
+  void_int *n_var_idx = NULL;
+  void_int *e_var_idx = NULL;
 
   int  nmstat;
 
@@ -167,7 +167,12 @@ file ID %d",
     }
 
     /* allocate space for the index variable */
-    n_var_idx = malloc((num_procs_in_file + 1) * sizeof(long long));
+    if (index_type == NC_INT64) {
+      n_var_idx = malloc((num_procs_in_file + 1) * sizeof(long long));
+    }
+    else {
+      n_var_idx = malloc((num_procs_in_file + 1) * sizeof(int));
+    }
     if (!n_var_idx) {
       exerrval = EX_MSG;
       sprintf(errmsg,
@@ -178,14 +183,16 @@ file ID %d",
     }
 
     /* and set the last value of the index */
-    n_var_idx[0] = 0;
 
     /* get the communication map info index */
-#if defined(NC_NETCDF4)
-    status = nc_get_var_longlong(exoid, n_varid_idx, &(n_var_idx[1]));
-#else
-    status = nc_get_var_int(exoid, n_varid_idx, &(n_var_idx[1]));
-#endif
+    if (index_type == NC_INT64) {
+      ((long long *)n_var_idx)[0] = 0;
+      status = nc_get_var_longlong(exoid, n_varid_idx, &((long long *)n_var_idx)[1]);
+    }
+    else {
+      ((int *)n_var_idx)[0] = 0;
+      status                = nc_get_var_int(exoid, n_varid_idx, &((int *)n_var_idx)[1]);
+    }
     if (status != NC_NOERR) {
       exerrval = status;
       sprintf(errmsg,
@@ -224,7 +231,12 @@ file ID %d",
     }
 
     /* allocate space for the index variable */
-    e_var_idx = malloc((num_procs_in_file + 1) * sizeof(long long));
+    if (index_type == NC_INT64) {
+      e_var_idx = malloc((num_procs_in_file + 1) * sizeof(long long));
+    }
+    else {
+      e_var_idx = malloc((num_procs_in_file + 1) * sizeof(int));
+    }
     if (!e_var_idx) {
       exerrval = EX_MSG;
       sprintf(errmsg,
@@ -235,14 +247,16 @@ file ID %d",
     }
 
     /* and set the first value of the index */
-    e_var_idx[0] = 0;
 
     /* get the communication map info index */
-#if defined NC_NETCDF4
-    status = nc_get_var_longlong(exoid, e_varid_idx, &(e_var_idx[1]));
-#else
-    status = nc_get_var_int(exoid, e_varid_idx, &(e_var_idx[1]));
-#endif
+    if (index_type == NC_INT64) {
+      ((long long *)e_var_idx)[0] = 0;
+      status = nc_get_var_longlong(exoid, e_varid_idx, &((long long *)e_var_idx)[1]);
+    }
+    else {
+      ((int *)e_var_idx)[0] = 0;
+      status                = nc_get_var_int(exoid, e_varid_idx, &((int *)e_var_idx)[1]);
+    }
     if (status != NC_NOERR) {
       exerrval = status;
       sprintf(errmsg,
@@ -283,14 +297,21 @@ file ID %d",
 
     /* now add up all of the nodal communications maps */
     ncnt_cmap = 0;
-    for(iproc=0; iproc < num_procs_in_file; iproc++) {
-      num_icm = n_var_idx[iproc+1] - n_var_idx[iproc];
-      for(icm=0; icm < num_icm; icm++)
-	if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
-	  ncnt_cmap += ((int64_t*)node_cmap_node_cnts)[((int64_t*)node_proc_ptrs)[iproc]+icm];
-	} else {
-	  ncnt_cmap += ((int*)node_cmap_node_cnts)[((int*)node_proc_ptrs)[iproc]+icm];
-	}
+    for (iproc = 0; iproc < num_procs_in_file; iproc++) {
+      if (index_type == NC_INT64) {
+        num_icm = ((int64_t *)n_var_idx)[iproc + 1] - ((int64_t *)n_var_idx)[iproc];
+      }
+      else {
+        num_icm = ((int *)n_var_idx)[iproc + 1] - ((int *)n_var_idx)[iproc];
+      }
+      for (icm = 0; icm < num_icm; icm++) {
+        if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
+          ncnt_cmap += ((int64_t *)node_cmap_node_cnts)[((int64_t *)node_proc_ptrs)[iproc] + icm];
+        }
+        else {
+          ncnt_cmap += ((int *)node_cmap_node_cnts)[((int *)node_proc_ptrs)[iproc] + icm];
+        }
+      }
     }
 
     if ((status = nc_def_dim(exoid, DIM_NCNT_CMAP, ncnt_cmap, &n_dimid[0])) != NC_NOERR) {
@@ -355,14 +376,21 @@ file ID %d",
 
     /* now add up all of the nodal communications maps */
     ecnt_cmap = 0;
-    for(iproc=0; iproc < num_procs_in_file; iproc++) {
-      num_icm = e_var_idx[iproc+1] - e_var_idx[iproc];
-      for(icm=0; icm < num_icm; icm++)
-	if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
-	  ecnt_cmap += ((int64_t*)elem_cmap_elem_cnts)[((int64_t*)elem_proc_ptrs)[iproc]+icm];
-	} else {
-	  ecnt_cmap += ((int*)elem_cmap_elem_cnts)[((int*)elem_proc_ptrs)[iproc]+icm];
-	}
+    for (iproc = 0; iproc < num_procs_in_file; iproc++) {
+      if (index_type == NC_INT64) {
+        num_icm = ((int64_t *)e_var_idx)[iproc + 1] - ((int64_t *)e_var_idx)[iproc];
+      }
+      else {
+        num_icm = ((int *)e_var_idx)[iproc + 1] - ((int *)e_var_idx)[iproc];
+      }
+      for (icm = 0; icm < num_icm; icm++) {
+        if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
+          ecnt_cmap += ((int64_t *)elem_cmap_elem_cnts)[((int64_t *)elem_proc_ptrs)[iproc] + icm];
+        }
+        else {
+          ecnt_cmap += ((int *)elem_cmap_elem_cnts)[((int *)elem_proc_ptrs)[iproc] + icm];
+        }
+      }
     }
 
     /* Add dimensions for elemental communications maps */
@@ -451,72 +479,89 @@ file ID %d",
     /* reset the index variable */
     nl_ncnt_cmap = 0;
 
-    for(iproc=0; iproc < num_procs_in_file; iproc++) {
+    for (iproc = 0; iproc < num_procs_in_file; iproc++) {
       size_t proc_ptr;
       if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
-	proc_ptr = ((int64_t*)node_proc_ptrs)[iproc];
-      } else {
-	proc_ptr = ((int*)node_proc_ptrs)[iproc];
+        proc_ptr = ((int64_t *)node_proc_ptrs)[iproc];
+      }
+      else {
+        proc_ptr = ((int *)node_proc_ptrs)[iproc];
       }
 
-      num_icm = n_var_idx[iproc+1] - n_var_idx[iproc];
-      for(icm=0; icm < num_icm; icm++) {
-	size_t cnt;
-	if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
-	  cnt = ((int64_t*)node_cmap_node_cnts)[proc_ptr+icm];
-	} else {
-	  cnt = ((int*)node_cmap_node_cnts)[proc_ptr+icm];
-	}
-	
-	start[0] = n_var_idx[iproc] + icm;
-	if (cnt > 0)
-	  nmstat = 1;
-	else
-	  nmstat = 0;
+      if (index_type == NC_INT64) {
+        num_icm = ((int64_t *)n_var_idx)[iproc + 1] - ((int64_t *)n_var_idx)[iproc];
+      }
+      else {
+        num_icm = ((int *)n_var_idx)[iproc + 1] - ((int *)n_var_idx)[iproc];
+      }
+      for (icm = 0; icm < num_icm; icm++) {
+        size_t cnt;
+        if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
+          cnt = ((int64_t *)node_cmap_node_cnts)[proc_ptr + icm];
+        }
+        else {
+          cnt = ((int *)node_cmap_node_cnts)[proc_ptr + icm];
+        }
 
-	if ((status = nc_put_var1_int(exoid, n_varid[0], start, &nmstat)) != NC_NOERR) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: unable to output variable in file ID %d", exoid);
-	  ex_err(func_name, errmsg, exerrval);
-	  return (EX_FATAL);
-	}
+        if (index_type == NC_INT64) {
+          start[0] = ((int64_t *)n_var_idx)[iproc] + icm;
+        }
+        else {
+          start[0] = ((int *)n_var_idx)[iproc] + icm;
+        }
+        if (cnt > 0) {
+          nmstat = 1;
+        }
+        else {
+          nmstat = 0;
+        }
 
-	/* increment to the next starting position */
-	nl_ncnt_cmap += cnt;
+        if ((status = nc_put_var1_int(exoid, n_varid[0], start, &nmstat)) != NC_NOERR) {
+          exerrval = status;
+          snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: unable to output variable in file ID %d", exoid);
+          ex_err(func_name, errmsg, exerrval);
+          return (EX_FATAL);
+        }
 
-	/* fill the data index variable */
-	status = nc_put_var1_longlong(exoid, n_varid_idx, start, &nl_ncnt_cmap);
+        /* increment to the next starting position */
+        nl_ncnt_cmap += cnt;
 
-	if (status != NC_NOERR) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: failed to output int elem map index in file ID %d",
-		  exoid);
-	  ex_err(func_name, errmsg, exerrval);
-	  return (EX_FATAL);
-	}
+        /* fill the data index variable */
+        status = nc_put_var1_longlong(exoid, n_varid_idx, start, &nl_ncnt_cmap);
+
+        if (status != NC_NOERR) {
+          exerrval = status;
+          snprintf(errmsg, MAX_ERR_LENGTH,
+                   "ERROR: failed to output int elem map index in file ID %d", exoid);
+          ex_err(func_name, errmsg, exerrval);
+          return (EX_FATAL);
+        }
       } /* End "for(icm=0; icm < num_icm; icm++)" */
 
       if (num_icm > 0) {
-	/* Output the nodal comm map IDs */
-	start[0] = n_var_idx[iproc];
-	count[0] =  num_icm;
-	if (ex_int64_status(exoid) & EX_IDS_INT64_API) {
-	  status = nc_put_vara_longlong(exoid, n_varid[1], start, count,
-					&((long long*)node_cmap_ids)[proc_ptr]);
-	} else {
-	  status = nc_put_vara_int(exoid, n_varid[1], start, count,
-				   &((int*)node_cmap_ids)[proc_ptr]);
-	}
-	if (status != NC_NOERR) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: failed to output variable in file ID %d", exoid);
-	  ex_err(func_name, errmsg, exerrval);
+        /* Output the nodal comm map IDs */
+        if (index_type == NC_INT64) {
+          start[0] = ((int64_t *)n_var_idx)[iproc];
+        }
+        else {
+          start[0] = ((int *)n_var_idx)[iproc];
+        }
+        count[0] = num_icm;
+        if (ex_int64_status(exoid) & EX_IDS_INT64_API) {
+          status = nc_put_vara_longlong(exoid, n_varid[1], start, count,
+                                        &((long long *)node_cmap_ids)[proc_ptr]);
+        }
+        else {
+          status =
+              nc_put_vara_int(exoid, n_varid[1], start, count, &((int *)node_cmap_ids)[proc_ptr]);
+        }
+        if (status != NC_NOERR) {
+          exerrval = status;
+          snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to output variable in file ID %d", exoid);
+          ex_err(func_name, errmsg, exerrval);
 
-	  return (EX_FATAL);
-	}
+          return (EX_FATAL);
+        }
       }
     } /* End "for(iproc=0; iproc < num_procs_in_file; iproc++)" */
 
@@ -554,71 +599,88 @@ file ID %d",
     /* reset the index variable */
     nl_ecnt_cmap = 0;
 
-    for(iproc=0; iproc < num_procs_in_file; iproc++) {
+    for (iproc = 0; iproc < num_procs_in_file; iproc++) {
       size_t proc_ptr;
       if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
-	proc_ptr = ((int64_t*)elem_proc_ptrs)[iproc];
-      } else {
-	proc_ptr = ((int*)elem_proc_ptrs)[iproc];
+        proc_ptr = ((int64_t *)elem_proc_ptrs)[iproc];
       }
-      num_icm = e_var_idx[iproc+1] - e_var_idx[iproc];
-      for(icm=0; icm < num_icm; icm++) {
+      else {
+        proc_ptr = ((int *)elem_proc_ptrs)[iproc];
+      }
+      if (index_type == NC_INT64) {
+        num_icm = ((int64_t *)e_var_idx)[iproc + 1] - ((int64_t *)e_var_idx)[iproc];
+      }
+      else {
+        num_icm = ((int *)e_var_idx)[iproc + 1] - ((int *)e_var_idx)[iproc];
+      }
+      for (icm = 0; icm < num_icm; icm++) {
 
-	size_t cnt;
-	if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
-	  cnt = ((int64_t*)elem_cmap_elem_cnts)[proc_ptr+icm];
-	} else {
-	  cnt = ((int*)elem_cmap_elem_cnts)[proc_ptr+icm];
-	}
+        size_t cnt;
+        if (ex_int64_status(exoid) & EX_BULK_INT64_API) {
+          cnt = ((int64_t *)elem_cmap_elem_cnts)[proc_ptr + icm];
+        }
+        else {
+          cnt = ((int *)elem_cmap_elem_cnts)[proc_ptr + icm];
+        }
 
-	start[0] = e_var_idx[iproc] + icm;
-	if (cnt > 0)
-	  nmstat = 1;
-	else
-	  nmstat = 0;
+        if (index_type == NC_INT64) {
+          start[0] = ((int64_t *)e_var_idx)[iproc] + icm;
+        }
+        else {
+          start[0] = ((int *)e_var_idx)[iproc] + icm;
+        }
+        if (cnt > 0) {
+          nmstat = 1;
+        }
+        else {
+          nmstat = 0;
+        }
 
-	if ((status = nc_put_var1_int(exoid, e_varid[0], start, &nmstat)) != NC_NOERR) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: unable to output variable in file ID %d", exoid);
-	  ex_err(func_name, errmsg, exerrval);
-	  return (EX_FATAL);
-	}
+        if ((status = nc_put_var1_int(exoid, e_varid[0], start, &nmstat)) != NC_NOERR) {
+          exerrval = status;
+          snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: unable to output variable in file ID %d", exoid);
+          ex_err(func_name, errmsg, exerrval);
+          return (EX_FATAL);
+        }
 
-	/* increment to the next starting position */
-	nl_ecnt_cmap += cnt;
+        /* increment to the next starting position */
+        nl_ecnt_cmap += cnt;
 
-	/* fill the data index variable */
-	status = nc_put_var1_longlong(exoid, e_varid_idx, start, &nl_ecnt_cmap);
+        /* fill the data index variable */
+        status = nc_put_var1_longlong(exoid, e_varid_idx, start, &nl_ecnt_cmap);
 
-	if (status != NC_NOERR) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: failed to output int elem map index in file ID %d",
-		  exoid);
-	  ex_err(func_name, errmsg, exerrval);
-	  return (EX_FATAL);
-	}
+        if (status != NC_NOERR) {
+          exerrval = status;
+          snprintf(errmsg, MAX_ERR_LENGTH,
+                   "ERROR: failed to output int elem map index in file ID %d", exoid);
+          ex_err(func_name, errmsg, exerrval);
+          return (EX_FATAL);
+        }
       } /* End "for(icm=0; icm < num_icm; icm++)" */
 
       if (num_icm > 0) {
-	/* Output the elemental comm map IDs */
-	start[0] = e_var_idx[iproc];
-	count[0] = num_icm;
-	if (ex_int64_status(exoid) & EX_IDS_INT64_API) {
-	  status = nc_put_vara_longlong(exoid, e_varid[1], start, count,
-					&((long long*)elem_cmap_ids)[proc_ptr]);
-	} else {
-	  status = nc_put_vara_int(exoid, e_varid[1], start, count,
-				   &((int*)elem_cmap_ids)[proc_ptr]);
-	}
-	if (status != NC_NOERR) {
-	  exerrval = status;
-	  sprintf(errmsg,
-		  "Error: failed to output variable in file ID %d", exoid);
-	  ex_err(func_name, errmsg, exerrval);
-	  return (EX_FATAL);
-	}
+        /* Output the elemental comm map IDs */
+        if (index_type == NC_INT64) {
+          start[0] = ((int64_t *)e_var_idx)[iproc];
+        }
+        else {
+          start[0] = ((int *)e_var_idx)[iproc];
+        }
+        count[0] = num_icm;
+        if (ex_int64_status(exoid) & EX_IDS_INT64_API) {
+          status = nc_put_vara_longlong(exoid, e_varid[1], start, count,
+                                        &((long long *)elem_cmap_ids)[proc_ptr]);
+        }
+        else {
+          status =
+              nc_put_vara_int(exoid, e_varid[1], start, count, &((int *)elem_cmap_ids)[proc_ptr]);
+        }
+        if (status != NC_NOERR) {
+          exerrval = status;
+          snprintf(errmsg, MAX_ERR_LENGTH, "ERROR: failed to output variable in file ID %d", exoid);
+          ex_err(func_name, errmsg, exerrval);
+          return (EX_FATAL);
+        }
       }
     } /* End "for(iproc=0; iproc < num_procs_in_file; iproc++)" */
 
