@@ -33,7 +33,7 @@
 
 #include <stk_io/StkMeshIoBroker.hpp>
 #include <assert.h>                     // for assert
-#include <init/Ionit_Initializer.h>     // for Initializer
+#include <Ionit_Initializer.h>     // for Initializer
 #include <stdint.h>                     // for int64_t
 #include <stdlib.h>                     // for exit, EXIT_FAILURE
 #include <iostream>                     // for operator<<, basic_ostream, etc
