@@ -31,30 +31,37 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 // 
 
+#include <gtest/gtest.h>                // for AssertHelper, ASSERT_TRUE, etc
 #include <stddef.h>                     // for size_t, NULL
 #include <iosfwd>                       // for ostringstream, ostream
 #include <set>                          // for set, etc
-#include <stdexcept>                    // for runtime_error, logic_error
+#include <stdexcept>                    // for logic_error, runtime_error
 #include <stk_mesh/base/EntityCommDatabase.hpp>  // for pack_entity_info, etc
-#include <stk_mesh/base/MetaData.hpp>   // for MetaData, put_field, etc
+#include <stk_mesh/base/MetaData.hpp>   // for MetaData, put_field
 #include <stk_mesh/fixtures/BoxFixture.hpp>  // for BoxFixture
 #include <stk_mesh/fixtures/HexFixture.hpp>  // for HexFixture, etc
 #include <stk_mesh/fixtures/QuadFixture.hpp>  // for QuadFixture
-#include <gtest/gtest.h>
 #include <string>                       // for string
 #include <utility>                      // for pair, make_pair
 #include <vector>                       // for vector, etc
+#include "mpi.h"                        // for MPI_COMM_WORLD, etc
 #include "stk_mesh/base/Bucket.hpp"     // for Bucket, Bucket::iterator
-#include "stk_mesh/base/BulkData.hpp"   // for BulkData, EntityLess, etc
+#include "stk_mesh/base/BulkData.hpp"   // for BulkData, etc
+#include "stk_mesh/base/BulkDataInlinedMethods.hpp"
 #include "stk_mesh/base/Entity.hpp"     // for Entity
-#include "stk_mesh/base/EntityKey.hpp"  // for EntityKey
+#include "stk_mesh/base/EntityCommListInfo.hpp"
+#include "stk_mesh/base/EntityKey.hpp"  // for EntityKey, operator<<
+#include "stk_mesh/base/EntityLess.hpp"  // for EntityLess
 #include "stk_mesh/base/Field.hpp"      // for Field
 #include "stk_mesh/base/FieldBase.hpp"  // for field_data
 #include "stk_mesh/base/Ghosting.hpp"   // for Ghosting, operator<<
 #include "stk_mesh/base/Types.hpp"      // for EntityProc, PartVector, etc
+#include "stk_mesh/fixtures/FixtureNodeSharing.hpp"
 #include "stk_topology/topology.hpp"    // for topology, etc
+#include "stk_topology/topology.hpp"    // for topology::num_nodes
 #include "stk_util/parallel/Parallel.hpp"  // for parallel_machine_size, etc
 #include "stk_util/parallel/ParallelComm.hpp"  // for CommAll, CommBuffer
+#include "unit_tests/BulkDataTester.hpp"  // for BulkDataTester
 namespace stk { namespace mesh { class Part; } }
 
 
