@@ -109,7 +109,7 @@ struct CrsMatrix {
 
 // Traits class for creating strided local views for embedded ensemble-based,
 // specialized for ensemble UQ scalar type
-template <typename ViewType>
+template <typename ViewType, typename Enabled = void>
 struct LocalViewTraits {
   typedef ViewType view_type;
   // typedef Kokkos::View<typename view_type::data_type,
@@ -127,6 +127,29 @@ struct LocalViewTraits {
 
 #if defined( KOKKOS_HAVE_CUDA )
 
+#if defined( KOKKOS_USING_EXPERIMENTAL_VIEW )
+template <typename ViewType>
+struct LocalViewTraits<
+  ViewType,
+  typename std::enable_if< std::is_same<typename ViewType::execution_space,
+                                        Kokkos::Cuda>::value &&
+                           Kokkos::is_view_mp_vector<ViewType>::value
+                         >::type > {
+  typedef ViewType view_type;
+  typedef typename Kokkos::LocalMPVectorView<view_type,1>::type local_view_type;
+  typedef typename local_view_type::value_type local_value_type;
+  static const bool use_team = true;
+
+  KOKKOS_INLINE_FUNCTION
+  static local_view_type create_local_view(const view_type& v,
+                                           const unsigned local_rank)
+  {
+    return Kokkos::partition<1>(v, local_rank);
+  }
+};
+
+#else
+
 template <typename T, typename L, typename M>
 struct LocalViewTraits< Kokkos::View<T,L,Kokkos::Cuda,M,Kokkos::Impl::ViewMPVectorContiguous> > {
   typedef Kokkos::Impl::ViewMPVectorContiguous Specialize;
@@ -162,6 +185,7 @@ struct LocalViewTraits< Kokkos::View<T,Kokkos::Cuda,M,V,Kokkos::Impl::ViewMPVect
     return local_v;
   }
 };
+#endif
 
 #endif /* #if defined( KOKKOS_HAVE_CUDA ) */
 
