@@ -150,6 +150,13 @@ bool& loc_printRCPNodeStatisticsOnExit()
 }
 
 
+bool& loc_printActiveRcpNodesOnExit()
+{
+  static bool s_loc_printActiveRcpNodesOnExit = true;
+  return s_loc_printActiveRcpNodesOnExit;
+}
+
+
 //
 // Other helper functions
 //
@@ -344,6 +351,18 @@ bool RCPNodeTracer::getPrintRCPNodeStatisticsOnExit()
 }
 
 
+void RCPNodeTracer::setPrintActiveRcpNodesOnExit(bool printActiveRcpNodesOnExit)
+{
+  loc_printActiveRcpNodesOnExit() = printActiveRcpNodesOnExit;
+}
+
+
+bool RCPNodeTracer::getPrintActiveRcpNodesOnExit()
+{
+  return loc_printActiveRcpNodesOnExit();
+}
+
+
 void RCPNodeTracer::printActiveRCPNodes(std::ostream &out)
 {
 #ifdef TEUCHOS_SHOW_ACTIVE_REFCOUNTPTR_NODE_TRACE
@@ -642,7 +661,9 @@ ActiveRCPNodesSetup::~ActiveRCPNodesSetup()
     {
       RCPNodeTracer::printRCPNodeStatistics(rcpNodeStatistics, std::cout);
     }
-    RCPNodeTracer::printActiveRCPNodes(std::cerr);
+    if (RCPNodeTracer::getPrintActiveRcpNodesOnExit()) {
+      RCPNodeTracer::printActiveRCPNodes(std::cerr);
+    }
     delete rcp_node_list();
     rcp_node_list() = 0;
   }
