@@ -1,4 +1,3 @@
-// @HEADER
 // ***********************************************************************
 //
 //          Tpetra: Templated Linear Algebra Services Package
@@ -148,13 +147,12 @@ namespace Tpetra {
 
   void
   Distributor::init (const Teuchos::RCP<const Teuchos::Comm<int> >& comm,
+                     const Teuchos::RCP<Teuchos::FancyOStream>& out,
                      const Teuchos::RCP<Teuchos::ParameterList>& plist)
   {
-    this->setVerbLevel (debug_ ? Teuchos::VERB_EXTREME : Teuchos::VERB_NONE);
-    this->setOStream (out_);
+    this->out_ = out.is_null () ?
+      Teuchos::getFancyOStream (Teuchos::rcpFromRef (std::cerr)) : out;
     if (! plist.is_null ()) {
-      // The input parameters may override the above verbosity level
-      // setting, if there is a "VerboseObject" sublist.
       this->setParameterList (plist);
     }
 
@@ -163,6 +161,10 @@ namespace Tpetra {
 #endif // TPETRA_DISTRIBUTOR_TIMERS
 
     if (debug_) {
+      TEUCHOS_TEST_FOR_EXCEPTION
+        (out_.is_null (), std::logic_error, "Tpetra::Distributor::init: debug_ "
+         "is true but out_ (pointer to the output stream) is NULL.  Please "
+         "report this bug to the Tpetra developers.");
       Teuchos::OSTab tab (out_);
       std::ostringstream os;
       os << comm_->getRank ()
@@ -173,7 +175,6 @@ namespace Tpetra {
 
   Distributor::Distributor (const Teuchos::RCP<const Teuchos::Comm<int> >& comm)
     : comm_ (comm)
-    , out_  (Teuchos::getFancyOStream (Teuchos::rcpFromRef (std::cerr)))
     , howInitialized_ (Details::DISTRIBUTOR_NOT_INITIALIZED)
     , sendType_ (Details::DISTRIBUTOR_SEND)
     , barrierBetween_ (barrierBetween_default)
@@ -189,13 +190,12 @@ namespace Tpetra {
     , lastRoundBytesRecv_ (0)
     , useDistinctTags_ (useDistinctTags_default)
   {
-    init (comm, Teuchos::null);
+    init (comm, Teuchos::null, Teuchos::null);
   }
 
   Distributor::Distributor (const Teuchos::RCP<const Teuchos::Comm<int> >& comm,
                             const Teuchos::RCP<Teuchos::FancyOStream>& out)
     : comm_ (comm)
-    , out_ (out.is_null () ? Teuchos::getFancyOStream (Teuchos::rcpFromRef (std::cerr)) : out)
     , howInitialized_ (Details::DISTRIBUTOR_NOT_INITIALIZED)
     , sendType_ (Details::DISTRIBUTOR_SEND)
     , barrierBetween_ (barrierBetween_default)
@@ -211,13 +211,12 @@ namespace Tpetra {
     , lastRoundBytesRecv_ (0)
     , useDistinctTags_ (useDistinctTags_default)
   {
-    init (comm, Teuchos::null);
+    init (comm, out, Teuchos::null);
   }
 
   Distributor::Distributor (const Teuchos::RCP<const Teuchos::Comm<int> >& comm,
                             const Teuchos::RCP<Teuchos::ParameterList>& plist)
     : comm_ (comm)
-    , out_ (Teuchos::getFancyOStream (Teuchos::rcpFromRef (std::cerr)))
     , howInitialized_ (Details::DISTRIBUTOR_NOT_INITIALIZED)
     , sendType_ (Details::DISTRIBUTOR_SEND)
     , barrierBetween_ (barrierBetween_default)
@@ -233,14 +232,13 @@ namespace Tpetra {
     , lastRoundBytesRecv_ (0)
     , useDistinctTags_ (useDistinctTags_default)
   {
-    init (comm, plist);
+    init (comm, Teuchos::null, plist);
   }
 
   Distributor::Distributor (const Teuchos::RCP<const Teuchos::Comm<int> >& comm,
                             const Teuchos::RCP<Teuchos::FancyOStream>& out,
                             const Teuchos::RCP<Teuchos::ParameterList>& plist)
     : comm_ (comm)
-    , out_ (out.is_null () ? Teuchos::getFancyOStream (Teuchos::rcpFromRef (std::cerr)) : out)
     , howInitialized_ (Details::DISTRIBUTOR_NOT_INITIALIZED)
     , sendType_ (Details::DISTRIBUTOR_SEND)
     , barrierBetween_ (barrierBetween_default)
@@ -256,7 +254,7 @@ namespace Tpetra {
     , lastRoundBytesRecv_ (0)
     , useDistinctTags_ (useDistinctTags_default)
   {
-    init (comm, plist);
+    init (comm, out, plist);
   }
 
   Distributor::Distributor (const Distributor & distributor)
@@ -291,11 +289,6 @@ namespace Tpetra {
     using Teuchos::RCP;
     using Teuchos::rcp;
 
-    this->setVerbLevel (distributor.getVerbLevel ());
-    this->setOStream (out_);
-    // The input parameters may override the above verbosity level
-    // setting, if there is a "VerboseObject" sublist.
-    //
     // Clone the right-hand side's ParameterList, so that this' list
     // is decoupled from the right-hand side's list.  We don't need to
     // do validation, since the right-hand side already has validated
@@ -312,6 +305,10 @@ namespace Tpetra {
 #endif // TPETRA_DISTRIBUTOR_TIMERS
 
     if (debug_) {
+      TEUCHOS_TEST_FOR_EXCEPTION
+        (out_.is_null (), std::logic_error, "Tpetra::Distributor::init: debug_ "
+         "is true but out_ (pointer to the output stream) is NULL.  Please "
+         "report this bug to the Tpetra developers.");
       Teuchos::OSTab tab (out_);
       std::ostringstream os;
       os << comm_->getRank ()
@@ -351,17 +348,6 @@ namespace Tpetra {
     std::swap (lastRoundBytesRecv_, rhs.lastRoundBytesRecv_);
     std::swap (useDistinctTags_, rhs.useDistinctTags_);
 
-    // Swap verbosity levels.
-    const Teuchos::EVerbosityLevel lhsVerb = this->getVerbLevel ();
-    const Teuchos::EVerbosityLevel rhsVerb = rhs.getVerbLevel ();
-    this->setVerbLevel (rhsVerb);
-    rhs.setVerbLevel (lhsVerb);
-
-    // Swap output streams.  We've swapped out_ above, but we have to
-    // tell the parent class VerboseObject about the swap.
-    this->setOStream (out_);
-    rhs.setOStream (rhs.out_);
-
     // Swap parameter lists.  If they are the same object, make a deep
     // copy first, so that modifying one won't modify the other one.
     RCP<ParameterList> lhsList = this->getNonconstParameterList ();
@@ -427,13 +413,6 @@ namespace Tpetra {
       "require that their corresponding receives have already been posted, "
       "and the only way to guarantee that in general is with a barrier.");
 
-    if (plist->isSublist ("VerboseObject")) {
-      // Read the "VerboseObject" sublist for (optional) verbosity
-      // settings.  We've set defaults already in Distributor's
-      // constructor, so we don't need this sublist to exist.
-      Teuchos::readVerboseObjectSublist (&*plist, this);
-    }
-
     // Now that we've validated the input list, save the results.
     sendType_ = sendType;
     barrierBetween_ = barrierBetween;
@@ -485,6 +464,12 @@ namespace Tpetra {
                 "CUDA GPUs.  Only enable this if you know for sure your MPI "
                 "library supports it.");
 
+    // mfh 24 Dec 2015: Tpetra no longer inherits from
+    // Teuchos::VerboseObject, so it doesn't need the "VerboseObject"
+    // sublist.  However, we retain the "VerboseObject" sublist
+    // anyway, for backwards compatibility (otherwise the above
+    // validation would fail with an invalid parameter name, should
+    // the user still want to provide this list).
     Teuchos::setupVerboseObjectSublist (&*plist);
     return Teuchos::rcp_const_cast<const ParameterList> (plist);
   }
