@@ -92,6 +92,135 @@ namespace Tpetra {
       clone (const InMapType& mapIn,
              const Teuchos::RCP<out_node_type>& node2);
     };
+
+    /// \class LocalMap
+    /// \brief "Local" part of Map suitable for Kokkos kernels.
+    ///
+    /// \warning This object's interface is not yet fixed.  We provide
+    ///   this object currently only as a service to advanced users.
+    ///
+    /// The "local" Map is suitable for use in Kokkos parallel
+    /// operations in the Map's native execution space, which is
+    /// <tt>Map::device_type::execution_space</tt>.
+    ///
+    /// By "local," we mean that the object performs no MPI
+    /// communication, and can only access information that would
+    /// never need MPI communication, no matter what kind of Map this
+    /// is.
+    template<class LocalOrdinal, class GlobalOrdinal, class DeviceType>
+    class LocalMap {
+    public:
+      LocalMap (const Details::FixedHashTable<GlobalOrdinal, LocalOrdinal, DeviceType>& glMap,
+                const Kokkos::View<const GlobalOrdinal*, DeviceType>& lgMap,
+                const GlobalOrdinal indexBase,
+                const GlobalOrdinal myMinGid,
+                const GlobalOrdinal myMaxGid,
+                const GlobalOrdinal firstContiguousGid,
+                const GlobalOrdinal lastContiguousGid,
+                const LocalOrdinal numLocalElements,
+                const bool contiguous) :
+        glMap_ (glMap),
+        lgMap_ (lgMap),
+        indexBase_ (indexBase),
+        myMinGid_ (myMinGid),
+        myMaxGid_ (myMaxGid),
+        firstContiguousGid_ (firstContiguousGid),
+        lastContiguousGid_ (lastContiguousGid),
+        numLocalElements_ (numLocalElements),
+        contiguous_ (contiguous)
+      {}
+
+      //! The number of indices that live on the calling process.
+      KOKKOS_INLINE_FUNCTION LocalOrdinal getNodeNumElements () const {
+        return numLocalElements_;
+      }
+
+      //! The (global) index base.
+      KOKKOS_INLINE_FUNCTION GlobalOrdinal getIndexBase () const {
+        return indexBase_;
+      }
+
+      /// \brief Whether the Map is (locally) contiguous.
+      ///
+      /// This is conservative; a Map is "contiguous" if and only if
+      /// it is stored that way.
+      KOKKOS_INLINE_FUNCTION bool isContiguous () const {
+        return contiguous_;
+      }
+
+      //! The minimum local index.
+      KOKKOS_INLINE_FUNCTION LocalOrdinal getMinLocalIndex () const {
+        return 0;
+      }
+
+      //! The maximum local index.
+      KOKKOS_INLINE_FUNCTION LocalOrdinal
+      getMaxLocalIndex () const
+      {
+        if (numLocalElements_ == 0) {
+          return Tpetra::Details::OrdinalTraits<LocalOrdinal>::invalid ();
+        } else { // Local indices are always zero-based.
+          return static_cast<LocalOrdinal> (numLocalElements_ - 1);
+        }
+      }
+
+      //! The minimum global index on the calling process.
+      KOKKOS_INLINE_FUNCTION GlobalOrdinal getMinGlobalIndex () const {
+        return myMinGid_;
+      }
+
+      //! The maximum global index on the calling process.
+      KOKKOS_INLINE_FUNCTION GlobalOrdinal getMaxGlobalIndex () const {
+        return myMaxGid_;
+      }
+
+      //! Get the local index corresponding to the given global index.
+      KOKKOS_INLINE_FUNCTION LocalOrdinal
+      getLocalElement (const GlobalOrdinal globalIndex) const
+      {
+        if (contiguous_) {
+          if (globalIndex < myMinGid_ || globalIndex > myMaxGid_) {
+            return Tpetra::Details::OrdinalTraits<LocalOrdinal>::invalid ();
+          }
+          return static_cast<LocalOrdinal> (globalIndex - myMinGid_);
+        }
+        else if (globalIndex >= firstContiguousGid_ &&
+                 globalIndex <= lastContiguousGid_) {
+          return static_cast<LocalOrdinal> (globalIndex - firstContiguousGid_);
+        }
+        else {
+          // If the given global index is not in the table, this returns
+          // the same value as OrdinalTraits<LocalOrdinal>::invalid().
+          return glMap_.get (globalIndex);
+        }
+      }
+
+      //! Get the global index corresponding to the given local index.
+      KOKKOS_INLINE_FUNCTION GlobalOrdinal
+      getGlobalElement (const LocalOrdinal localIndex) const
+      {
+        if (localIndex < getMinLocalIndex () || localIndex > getMaxLocalIndex ()) {
+          return Tpetra::Details::OrdinalTraits<GlobalOrdinal>::invalid ();
+        }
+        if (isContiguous ()) {
+          return getMinGlobalIndex () + localIndex;
+        }
+        else {
+          return lgMap_(localIndex);
+        }
+      }
+
+    private:
+      Details::FixedHashTable<GlobalOrdinal, LocalOrdinal, DeviceType> glMap_;
+      Kokkos::View<const GlobalOrdinal*, DeviceType> lgMap_;
+      GlobalOrdinal indexBase_;
+      GlobalOrdinal myMinGid_;
+      GlobalOrdinal myMaxGid_;
+      GlobalOrdinal firstContiguousGid_;
+      GlobalOrdinal lastContiguousGid_;
+      LocalOrdinal numLocalElements_;
+      bool contiguous_;
+    };
   } // namespace Details
 
   template<class Node>
@@ -203,7 +332,7 @@ namespace Tpetra {
   /// <li>the set of global indices (over all processes) forms an
   ///   interval, </li>
   /// <li>every global index in that interval is owned by exactly one
-  ///   process in the Map's communicator, <li>
+  ///   process in the Map's communicator, </li>
   /// <li>the (ordered) list of global indices on each process p in
   ///   the Map's communicator forms a contiguous interval, and </li>
   /// <li>if process p owns a global index \f$g_p\f$ and process q
@@ -268,6 +397,31 @@ namespace Tpetra {
     //! The type of the Kokkos Node.
     typedef Node node_type;
 
+    /// \brief The Kokkos device type over which to allocate Views and
+    ///   perform work.
+    ///
+    /// A Kokkos::Device is an (execution_space, memory_space) pair.
+    /// It defines where the Map's data live, and where Map might
+    /// choose to execute parallel kernels.
+    typedef typename Kokkos::Device<typename Node::execution_space,
+                                    typename Node::memory_space> device_type;
+
+    /// \brief Type of the "local" Map.
+    ///
+    /// \warning This object's interface is not yet fixed.  We provide
+    ///   this object currently only as a service to advanced users.
+    ///
+    /// The "local" Map is suitable for use in Kokkos parallel
+    /// operations in the Map's native execution space, which is
+    /// <tt>device_type::execution_space</tt>.
+    ///
+    /// By "local," we mean that the object performs no MPI
+    /// communication, and can only access information that would
+    /// never need MPI communication, no matter what kind of Map this
+    /// is.
+    typedef Details::LocalMap<LocalOrdinal, GlobalOrdinal, device_type>
+      local_map_type;
+
     //@}
     //! @name Constructors and destructor
     //@{
@@ -544,6 +698,12 @@ namespace Tpetra {
     ///   Teuchos::OrdinalTraits<GlobalOrdinal>::invalid().
     GlobalOrdinal getGlobalElement (LocalOrdinal localIndex) const;
 
+    /// \brief Get the local Map for Kokkos kernels.
+    ///
+    /// \warning The interface of the local Map object is SUBJECT TO
+    ///   CHANGE and is for EXPERT USERS ONLY.
+    local_map_type getLocalMap () const;
+
     /// \brief Return the process ranks and corresponding local
     ///   indices for the given global indices.
     ///
@@ -955,10 +1115,6 @@ namespace Tpetra {
     /// mutually exclusive terms.
     bool distributed_;
 
-    //! The Kokkos device type over which to allocate Views and perform work.
-    typedef typename Kokkos::Device<typename Node::execution_space,
-                                    typename Node::memory_space> device_type;
-
     /// \brief A mapping from local IDs to global IDs.
     ///
     /// By definition, this mapping is local; it only contains global
@@ -975,11 +1131,14 @@ namespace Tpetra {
     /// The potential for on-demand creation is why this member datum
     /// is declared "mutable".  Note that other methods, such as
     /// describe(), may invoke getNodeElementList().
-    mutable Kokkos::DualView<GlobalOrdinal*, device_type> lgMap_;
+    ///
+    /// NOTE: With CUDA, we assume UVM, in that host code can access
+    /// the entries of this View.
+    mutable Kokkos::View<GlobalOrdinal*, device_type> lgMap_;
 
-    //! Type of the table that maps global IDs to local IDs.
-    typedef Details::FixedHashTable<GlobalOrdinal, LocalOrdinal,
-                                    device_type> global_to_local_table_type;
+    //! Type of a mapping from global IDs to local IDs.
+    typedef Details::FixedHashTable<GlobalOrdinal, LocalOrdinal, device_type>
+      global_to_local_table_type;
 
     /// \brief A mapping from global IDs to local IDs.
     ///
@@ -1200,10 +1359,20 @@ namespace Tpetra {
     clone (const InMapType& mapIn,
            const Teuchos::RCP<out_node_type>& nodeOut)
     {
-      typedef ::Tpetra::Directory<typename OutMapType::local_ordinal_type,
-                                  typename OutMapType::global_ordinal_type,
+      static_assert (std::is_same<typename OutMapType::local_ordinal_type,
+                                  typename InMapType::local_ordinal_type>::value,
+                     "Tpetra::Map clone: The LocalOrdinal template parameter "
+                     "of the input and output Map types must be the same.");
+      static_assert (std::is_same<typename OutMapType::global_ordinal_type,
+                                  typename InMapType::global_ordinal_type>::value,
+                     "Tpetra::Map clone: The GlobalOrdinal template parameter "
+                     "of the input and output Map types must be the same.");
+      typedef typename OutMapType::local_ordinal_type LO;
+      typedef typename OutMapType::global_ordinal_type GO;
+      typedef ::Tpetra::Directory<LO, GO,
                                   typename OutMapType::node_type> out_dir_type;
       typedef typename OutMapType::global_to_local_table_type out_table_type;
+      typedef typename OutMapType::device_type out_device_type;
 
       OutMapType mapOut; // Make an empty Map.
 
@@ -1223,14 +1392,24 @@ namespace Tpetra {
       mapOut.uniform_           = mapIn.uniform_;
       mapOut.contiguous_        = mapIn.contiguous_;
       mapOut.distributed_       = mapIn.distributed_;
-      mapOut.lgMap_             = mapIn.lgMap_;
+      {
+        // mfh 25 Dec 2015, 11 Jan 2016: We really only need to make a
+        // deep copy if the two Map types have different memory
+        // spaces.  However, if you're calling clone(), it is likely
+        // the case that the memory spaces differ, so it doesn't hurt
+        // to make a deep copy here.
+        Kokkos::View<GO*, out_device_type>
+          lgMapOut ("lgMap", mapIn.lgMap_.dimension_0 ());
+        Kokkos::deep_copy (lgMapOut, mapIn.lgMap_);
+        mapOut.lgMap_ = lgMapOut; // cast to const
+      }
       // This makes a deep copy only if necessary.  We could have
       // defined operator= to do this, but that would violate
       // expectations.  (Kokkos::View::operator= only does a shallow
       // copy, EVER.)
-      mapOut.glMap_             = out_table_type (mapIn.glMap_);
+      mapOut.glMap_ = out_table_type (mapIn.glMap_);
       // New Map gets the new Node instance.
-      mapOut.node_              = nodeOut;
+      mapOut.node_ = nodeOut;
 
       // We could cleverly clone the Directory here if it is
       // initialized, but there is no harm in simply creating it
