@@ -177,8 +177,7 @@ dot (const RV& R, const XMV& X, const YMV& Y,
       typename RV::non_const_value_type* >::type,
     typename RV::array_layout,
     typename RV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RV::specialize> RV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RV_Internal;
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
       XMV::rank == 1,
@@ -186,8 +185,7 @@ dot (const RV& R, const XMV& X, const YMV& Y,
       typename XMV::const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
       YMV::rank == 1,
@@ -195,8 +193,7 @@ dot (const RV& R, const XMV& X, const YMV& Y,
       typename YMV::const_value_type** >::type,
     typename YMV::array_layout,
     typename YMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename YMV::specialize> YMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > YMV_Internal;
 
   RV_Internal R_internal = R;
   XMV_Internal X_internal = X;
@@ -244,8 +241,7 @@ fill (const XMV& X, const typename XMV::non_const_value_type& val)
       typename XMV::non_const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   XMV_Internal X_internal = X;
   Impl::Fill<XMV_Internal>::fill (X_internal, val);
@@ -294,8 +290,7 @@ nrm2_squared (const RV& R, const XMV& X)
       typename RV::non_const_value_type* >::type,
     typename RV::array_layout,
     typename RV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RV::specialize> RV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RV_Internal;
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
       XMV::rank == 1,
@@ -303,8 +298,7 @@ nrm2_squared (const RV& R, const XMV& X)
       typename XMV::const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   RV_Internal R_internal = R;
   XMV_Internal X_internal = X;
@@ -365,8 +359,7 @@ nrm1 (const RV& R, const XMV& X)
       typename RV::non_const_value_type* >::type,
     typename RV::array_layout,
     typename RV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RV::specialize> RV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RV_Internal;
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
       XMV::rank == 1,
@@ -374,8 +367,7 @@ nrm1 (const RV& R, const XMV& X)
       typename XMV::const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   RV_Internal R_internal = R;
   XMV_Internal X_internal = X;
@@ -435,8 +427,7 @@ nrmInf (const RV& R, const XMV& X)
       typename RV::non_const_value_type* >::type,
     typename RV::array_layout,
     typename RV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RV::specialize> RV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RV_Internal;
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
       XMV::rank == 1,
@@ -444,8 +435,7 @@ nrmInf (const RV& R, const XMV& X)
       typename XMV::const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   RV_Internal R_internal = R;
   XMV_Internal X_internal = X;
@@ -479,8 +469,7 @@ struct GetInternalTypeForAxpby<T, true> {
   typedef Kokkos::View<typename T::const_value_type*,
                        typename T::array_layout,
                        typename T::device_type,
-                       Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-                       typename T::specialize> type;
+                       Kokkos::MemoryTraits<Kokkos::Unmanaged> > type;
 };
 
   // typedef typename Kokkos::Impl::if_c<
@@ -488,8 +477,7 @@ struct GetInternalTypeForAxpby<T, true> {
   //   Kokkos::View<typename BV::const_value_type*,
   //     typename BV::array_layout,
   //     typename BV::device_type,
-  //     Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-  //     typename BV::specialize>, // use the unmanaged version of BV,
+  //     Kokkos::MemoryTraits<Kokkos::Unmanaged> >, // use the unmanaged version of BV,
   //   BV >::type BV_Internal; // else just use BV.
 
 } // namespace (anonymous)
@@ -535,8 +523,7 @@ axpby (const AV& a, const XMV& X, const BV& b, const YMV& Y)
       typename XMV::const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
   typedef typename GetInternalTypeForAxpby<
     BV, Kokkos::Impl::is_view<BV>::value>::type BV_Internal;
   typedef Kokkos::View<
@@ -546,8 +533,7 @@ axpby (const AV& a, const XMV& X, const BV& b, const YMV& Y)
       typename YMV::non_const_value_type** >::type,
     typename YMV::array_layout,
     typename YMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename YMV::specialize> YMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > YMV_Internal;
 
   AV_Internal  a_internal = a;
   XMV_Internal X_internal = X;
@@ -608,8 +594,7 @@ scal (const RMV& R, const AV& a, const XMV& X)
       typename RMV::non_const_value_type** >::type,
     typename RMV::array_layout,
     typename RMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RMV::specialize> RMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RMV_Internal;
   typedef typename GetInternalTypeForAxpby<
     AV, Kokkos::Impl::is_view<AV>::value>::type AV_Internal;
   typedef Kokkos::View<
@@ -619,8 +604,7 @@ scal (const RMV& R, const AV& a, const XMV& X)
       typename XMV::non_const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   RMV_Internal R_internal = R;
   AV_Internal  a_internal = a;
@@ -686,8 +670,7 @@ abs (const RMV& R, const XMV& X)
       typename RMV::non_const_value_type** >::type,
     typename RMV::array_layout,
     typename RMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RMV::specialize> RMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RMV_Internal;
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
       XMV::rank == 1,
@@ -695,8 +678,7 @@ abs (const RMV& R, const XMV& X)
       typename XMV::non_const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   RMV_Internal R_internal = R;
   XMV_Internal X_internal = X;
@@ -770,8 +752,7 @@ update (const typename XMV::non_const_value_type& alpha, const XMV& X,
       typename XMV::const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
@@ -780,8 +761,7 @@ update (const typename XMV::non_const_value_type& alpha, const XMV& X,
       typename YMV::const_value_type** >::type,
     typename YMV::array_layout,
     typename YMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename YMV::specialize> YMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > YMV_Internal;
 
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
@@ -790,8 +770,7 @@ update (const typename XMV::non_const_value_type& alpha, const XMV& X,
       typename ZMV::non_const_value_type** >::type,
     typename ZMV::array_layout,
     typename ZMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename ZMV::specialize> ZMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > ZMV_Internal;
 
   XMV_Internal X_internal = X;
   YMV_Internal Y_internal = Y;
@@ -854,8 +833,7 @@ reciprocal (const RMV& R, const XMV& X)
       typename RMV::non_const_value_type** >::type,
     typename RMV::array_layout,
     typename RMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RMV::specialize> RMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RMV_Internal;
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
       XMV::rank == 1,
@@ -863,8 +841,7 @@ reciprocal (const RMV& R, const XMV& X)
       typename XMV::non_const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   RMV_Internal R_internal = R;
   XMV_Internal X_internal = X;
@@ -916,8 +893,7 @@ sum (const RV& R, const XMV& X)
       typename RV::non_const_value_type* >::type,
     typename RV::array_layout,
     typename RV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RV::specialize> RV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RV_Internal;
 
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
@@ -926,8 +902,7 @@ sum (const RV& R, const XMV& X)
       typename XMV::const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   RV_Internal R_internal = R;
   XMV_Internal X_internal = X;
@@ -989,8 +964,7 @@ nrm2w_squared (const RV& R, const XMV& X, const XMV& W)
       typename RV::non_const_value_type* >::type,
     typename RV::array_layout,
     typename RV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename RV::specialize> RV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > RV_Internal;
 
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
@@ -999,8 +973,7 @@ nrm2w_squared (const RV& R, const XMV& X, const XMV& W)
       typename XMV::const_value_type** >::type,
     typename XMV::array_layout,
     typename XMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename XMV::specialize> XMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > XMV_Internal;
 
   RV_Internal R_internal = R;
   XMV_Internal X_internal = X;
@@ -1062,14 +1035,12 @@ mult (typename CMV::const_value_type& c,
       typename CMV::non_const_value_type** >::type,
     typename CMV::array_layout,
     typename CMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename CMV::specialize> CMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > CMV_Internal;
   typedef Kokkos::View<
     typename AV::const_value_type*,
     typename AV::array_layout,
     typename AV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename AV::specialize> AV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > AV_Internal;
   typedef Kokkos::View<
     typename Kokkos::Impl::if_c<
       BMV::rank == 1,
@@ -1077,8 +1048,7 @@ mult (typename CMV::const_value_type& c,
       typename BMV::const_value_type** >::type,
     typename BMV::array_layout,
     typename BMV::device_type,
-    Kokkos::MemoryTraits<Kokkos::Unmanaged>,
-    typename BMV::specialize> BMV_Internal;
+    Kokkos::MemoryTraits<Kokkos::Unmanaged> > BMV_Internal;
 
   CMV_Internal C_internal = C;
   AV_Internal A_internal = A;
