@@ -62,13 +62,13 @@
 
 namespace Xpetra {
 
-  template <class Scalar = CrsMatrix<>::scalar_type,
-            class LocalOrdinal =
-              typename CrsMatrix<Scalar>::local_ordinal_type,
-            class GlobalOrdinal =
-              typename CrsMatrix<Scalar, LocalOrdinal>::global_ordinal_type,
-            class Node =
-              typename CrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal>::node_type>
+  template <class Scalar /*= CrsMatrix<>::scalar_type*/,
+            class LocalOrdinal /*=
+              typename CrsMatrix<Scalar>::local_ordinal_type*/,
+            class GlobalOrdinal /*=
+              typename CrsMatrix<Scalar, LocalOrdinal>::global_ordinal_type*/,
+            class Node /*=
+              typename CrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal>::node_type*/>
   class CrsMatrixFactory {
   private:
     //! Private constructor. This is a static class.
@@ -199,12 +199,17 @@ namespace Xpetra {
 
   };
 
+// we need the Epetra specialization only if Epetra is enabled
+#if (defined(HAVE_XPETRA_EPETRA) && !defined(XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES))
+
+  // Specializtion for SC=double, LO=int, GO=int and Node=EpetraNode
+  // Used both for Epetra and Tpetra
   template <>
-  class CrsMatrixFactory<double, int, int> {
+  class CrsMatrixFactory<double, int, int, EpetraNode> {
     typedef double Scalar;
     typedef int LocalOrdinal;
     typedef int GlobalOrdinal;
-    typedef CrsMatrix<double, int, GlobalOrdinal>::node_type Node;
+    typedef EpetraNode Node;
 
   private:
     //! Private constructor. This is a static class.
@@ -220,12 +225,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, maxNumEntriesPerRow, pftype, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<int>(rowMap, maxNumEntriesPerRow, pftype, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<int,Node>(rowMap, maxNumEntriesPerRow, pftype, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -238,12 +239,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, NumEntriesPerRowToAlloc, pftype, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<int>(rowMap, NumEntriesPerRowToAlloc, pftype, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<int,Node>(rowMap, NumEntriesPerRowToAlloc, pftype, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -257,12 +254,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, colMap, maxNumEntriesPerRow, pftype, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<int>(rowMap, colMap, maxNumEntriesPerRow, pftype, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<int,Node>(rowMap, colMap, maxNumEntriesPerRow, pftype, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -276,12 +269,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, colMap, NumEntriesPerRowToAlloc, pftype, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<int>(rowMap, colMap, NumEntriesPerRowToAlloc, pftype, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<int,Node>(rowMap, colMap, NumEntriesPerRowToAlloc, pftype, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -295,12 +284,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(graph, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (graph->getRowMap()->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<int>(graph, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<int,Node>(graph, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -313,15 +298,10 @@ namespace Xpetra {
 #ifdef HAVE_XPETRA_TPETRA
       if (sourceMatrix->getRowMap()->lib() == UseTpetra)
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(sourceMatrix,importer,domainMap,rangeMap,params) );
-
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (sourceMatrix->getRowMap()->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<int>(sourceMatrix,importer,domainMap,rangeMap,params) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<int,Node>(sourceMatrix,importer,domainMap,rangeMap,params) );
 
       XPETRA_FACTORY_END;
     }
@@ -333,15 +313,10 @@ namespace Xpetra {
 #ifdef HAVE_XPETRA_TPETRA
       if (sourceMatrix->getRowMap()->lib() == UseTpetra)
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(sourceMatrix,exporter,domainMap,rangeMap,params) );
-
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (sourceMatrix->getRowMap()->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<int>(sourceMatrix,exporter,domainMap,rangeMap,params) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<int,Node>(sourceMatrix,exporter,domainMap,rangeMap,params) );
 
       XPETRA_FACTORY_END;
     }
@@ -359,25 +334,25 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, colMap, lclMatrix, params));
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<int>(rowMap, colMap, lclMatrix, params) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<int,Node>(rowMap, colMap, lclMatrix, params) );
+
       XPETRA_FACTORY_END;
     }
 #endif
 
   };
+#endif
+
+// we need the Epetra specialization only if Epetra is enabled
+#if (defined(HAVE_XPETRA_EPETRA) && !defined(XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES))
 
-#ifdef HAVE_XPETRA_INT_LONG_LONG
   template <>
-  class CrsMatrixFactory<double, int, long long> {
+  class CrsMatrixFactory<double, int, long long, EpetraNode> {
     typedef double Scalar;
     typedef int LocalOrdinal;
     typedef long long GlobalOrdinal;
-    typedef CrsMatrix<double, int, GlobalOrdinal>::node_type Node;
+    typedef EpetraNode Node;
 
   private:
     //! Private constructor. This is a static class.
@@ -393,12 +368,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, maxNumEntriesPerRow, pftype, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<long long>(rowMap, maxNumEntriesPerRow, pftype, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<long long, Node>(rowMap, maxNumEntriesPerRow, pftype, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -411,12 +382,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, NumEntriesPerRowToAlloc, pftype, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<long long>(rowMap, NumEntriesPerRowToAlloc, pftype, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<long long, Node>(rowMap, NumEntriesPerRowToAlloc, pftype, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -430,12 +397,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, colMap, maxNumEntriesPerRow, pftype, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<long long>(rowMap, colMap, maxNumEntriesPerRow, pftype, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<long long, Node>(rowMap, colMap, maxNumEntriesPerRow, pftype, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -449,12 +412,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, colMap, NumEntriesPerRowToAlloc, pftype, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<long long>(rowMap, colMap, NumEntriesPerRowToAlloc, pftype, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<long long, Node>(rowMap, colMap, NumEntriesPerRowToAlloc, pftype, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -468,12 +427,8 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(graph, plist) );
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES
       if (graph->getRowMap()->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<long long>(graph, plist) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<long long, Node>(graph, plist) );
 
       XPETRA_FACTORY_END;
     }
@@ -486,15 +441,10 @@ namespace Xpetra {
 #ifdef HAVE_XPETRA_TPETRA
       if (sourceMatrix->getRowMap()->lib() == UseTpetra)
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(sourceMatrix,importer,domainMap,rangeMap,params) );
-
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES
       if (sourceMatrix->getRowMap()->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<long long>(sourceMatrix,importer,domainMap,rangeMap,params) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<long long, Node>(sourceMatrix,importer,domainMap,rangeMap,params) );
 
       XPETRA_FACTORY_END;
     }
@@ -506,15 +456,10 @@ namespace Xpetra {
 #ifdef HAVE_XPETRA_TPETRA
       if (sourceMatrix->getRowMap()->lib() == UseTpetra)
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(sourceMatrix,exporter,domainMap,rangeMap,params) );
-
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_64BIT_GLOBAL_INDICES
       if (sourceMatrix->getRowMap()->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<long long>(sourceMatrix,exporter,domainMap,rangeMap,params) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<long long, Node>(sourceMatrix,exporter,domainMap,rangeMap,params) );
 
       XPETRA_FACTORY_END;
     }
@@ -532,18 +477,14 @@ namespace Xpetra {
         return rcp( new TpetraCrsMatrix<Scalar, LocalOrdinal, GlobalOrdinal, Node>(rowMap, colMap, lclMatrix, params));
 #endif
 
-#ifdef HAVE_XPETRA_EPETRA
-#ifndef XPETRA_EPETRA_NO_32BIT_GLOBAL_INDICES
       if (rowMap->lib() == UseEpetra)
-        return rcp( new EpetraCrsMatrixT<long long>(rowMap, colMap, lclMatrix, params) );
-#endif
-#endif
+        return rcp( new EpetraCrsMatrixT<long long, Node>(rowMap, colMap, lclMatrix, params) );
       XPETRA_FACTORY_END;
     }
 #endif
 
   };
-#endif // HAVE_XPETRA_INT_LONG_LONG
+#endif
 
 }
 
