@@ -68,10 +68,11 @@
 
 namespace {
 #ifdef HAVE_XPETRA_EPETRA
+typedef KokkosClassic::DefaultNode::DefaultNodeType Node;
 #ifndef XPETRA_TEST_USE_LONGLONG_GO
-  typedef Xpetra::EpetraMap EpetraMap;
+  typedef Xpetra::EpetraMapT<int,Node> EpetraMap;
 #else
-  typedef Xpetra::EpetraMap64 EpetraMap;
+  typedef Xpetra::EpetraMapT<long long, Node> EpetraMap;
 #endif
 #endif
   using Teuchos::Array;
@@ -438,11 +439,15 @@ namespace {
 
 #ifndef XPETRA_TEST_USE_LONGLONG_GO
 #ifdef HAVE_XPETRA_EPETRA
+#ifdef HAVE_XPETRA_TPETRA_INST_INT_INT
       UNIT_TEST_GROUP_ORDINAL_(EpetraMap, int , int)
 #endif
+#endif
 #ifdef HAVE_XPETRA_TPETRA
+#ifdef HAVE_XPETRA_TPETRA_INST_INT_INT
       UNIT_TEST_GROUP_ORDINAL(int , int)
 #endif
+#endif
 #else
     typedef long long LongLongInt;
 #ifdef HAVE_XPETRA_EPETRA
